/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_mgWF76js, &hTable_5jAlSjAd);
  numBytes += sTabread_init(&sTabread_Z694mfXo, &hTable_5jAlSjAd, true);
  numBytes += sRPole_init(&sRPole_vHsC0qoq);
  numBytes += sEnv_init(&sEnv_EDBy3fn0, 1024, 512);
  numBytes += sLine_init(&sLine_Ebn0cJiy);
  numBytes += cSlice_init(&cSlice_OYtzs8Ia, 1, -1);
  numBytes += cSlice_init(&cSlice_4LD6uEUb, 1, -1);
  numBytes += cVar_init_f(&cVar_P3QM5m3U, 0.0f);
  numBytes += cIf_init(&cIf_cffhYxMg, false);
  numBytes += cBinop_init(&cBinop_SkCgn2S6, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_rTMcVFyX, 1, -1);
  numBytes += cSlice_init(&cSlice_MgDjxtbC, 1, -1);
  numBytes += cVar_init_f(&cVar_hcFuA2kT, 0.0f);
  numBytes += cIf_init(&cIf_U3SRMSXU, false);
  numBytes += cBinop_init(&cBinop_jO6KZGhD, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_Bc9ex0y5, 0.0f);
  numBytes += cVar_init_f(&cVar_wz4ydtnF, 0.0f);
  numBytes += cBinop_init(&cBinop_9cqsAl4H, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_vqjdRYmT, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_KYchHO4J, 2, 1);
  numBytes += cSlice_init(&cSlice_gWP8fYSq, 1, 1);
  numBytes += cSlice_init(&cSlice_qzsYUl8C, 0, 1);
  numBytes += cVar_init_f(&cVar_1tO9vWgI, 0.0f);
  numBytes += cIf_init(&cIf_Q938XZQb, false);
  numBytes += cIf_init(&cIf_XR1JivBu, false);
  numBytes += cIf_init(&cIf_ubOExjmB, false);
  numBytes += cIf_init(&cIf_lUXh9sq0, false);
  numBytes += cIf_init(&cIf_aGchclBH, false);
  numBytes += cBinop_init(&cBinop_yw2ghEXg, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_DsTGSJMj, 10.0f);
  numBytes += cPack_init(&cPack_U47tYTWL, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_682Dtp0l, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_JpnZ19Zl, 10.0f);
  numBytes += cPack_init(&cPack_se3o1lKo, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_9OZhzm7n, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_UhcUutbQ, 10.0f);
  numBytes += cPack_init(&cPack_ocux1CLv, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_MfTxJU1o, 1e-07f);
  numBytes += cIf_init(&cIf_I71ZpUXT, true);
  numBytes += cVar_init_f(&cVar_BapuIkQf, 1e-07f);
  numBytes += cVar_init_f(&cVar_VbT7TKCL, 1e-07f);
  numBytes += sVarf_init(&sVarf_PkprEZIW, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_TlcGmXaQ, 0.0f);
  numBytes += cVar_init_f(&cVar_K2lg5SuR, 20.0f);
  numBytes += cBinop_init(&cBinop_bYfDTb2M, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Ua2EOOcC, 0.0f);
  numBytes += cSlice_init(&cSlice_B7zgN17Z, 1, -1);
  numBytes += cSlice_init(&cSlice_fvi2UNdR, 1, -1);
  numBytes += cVar_init_f(&cVar_DEtWgxTW, 0.0f);
  numBytes += cVar_init_f(&cVar_CwYLi1yh, 20.0f);
  numBytes += cVar_init_f(&cVar_AF2c04EU, 0.0f);
  numBytes += cVar_init_f(&cVar_afr4xrUK, 0.0f);
  numBytes += cVar_init_f(&cVar_bZTNR3et, 0.0f);
  numBytes += cSlice_init(&cSlice_HBpFMKwN, 1, 1);
  numBytes += cSlice_init(&cSlice_WEdTTQne, 0, 1);
  numBytes += cBinop_init(&cBinop_DuUTXOoH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bPdd3BNc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VpejE30G, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_oF5rlLfQ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TAc8Ku27, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_ORcr7vXa, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_O84zO5Zo, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_dfgAFJCW, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_G5QlZCON, 5.0f);
  numBytes += cVar_init_f(&cVar_T08qFyEm, 500.0f);
  numBytes += cBinop_init(&cBinop_r8Bxi70t, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FmPbJQ6p, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qjdSRMNg, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ogZWKMMu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_nPmFBmkJ, 0.0f);
  numBytes += hTable_init(&hTable_5jAlSjAd, 256);
  numBytes += cTabhead_init(&cTabhead_bjpPhRXP, &hTable_5jAlSjAd);
  numBytes += cVar_init_s(&cVar_Az54KbzI, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_EiZPTMoY, 8.0f);
  numBytes += cDelay_init(this, &cDelay_guFTXGDh, 0.0f);
  numBytes += cBinop_init(&cBinop_EM2qEhd7, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_QQIuwtou, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_zjsDO6P7, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_6CsOFCSZ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_R4tCFbL8, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_ri7Cn2u5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NBkbhyJa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qZvVEHEV, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_EDBy3fn0);
  cPack_free(&cPack_U47tYTWL);
  cPack_free(&cPack_se3o1lKo);
  cPack_free(&cPack_ocux1CLv);
  hTable_free(&hTable_5jAlSjAd);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_5jAlSjAd; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FJaHOunS_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sdf4QKvy_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IW1LDMUL_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k5eQtnuv_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eUTPiA0Z_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bJ6xeIBo_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r1CI0odu_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gmI8uJSz_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yjn0qvhH_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_32HpZLYW_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7XecWmJH_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uRbITAPg_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ekF8Yfdm_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VYGcRkXp_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5bVdkE0m_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tXGTMRcA_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NpODmNVo_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_EDBy3fn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9cqsAl4H, HV_BINOP_GREATER_THAN, 0, m, &cBinop_9cqsAl4H_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vqjdRYmT, HV_BINOP_LESS_THAN, 0, m, &cBinop_vqjdRYmT_sendMessage);
}

void Heavy_vSwell::cSwitchcase_y6ulEIhF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OYtzs8Ia, 0, m, &cSlice_OYtzs8Ia_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4LD6uEUb, 0, m, &cSlice_4LD6uEUb_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rjDrclvc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FW0Nnspj_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_OYtzs8Ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_P3QM5m3U, 0, m, &cVar_P3QM5m3U_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_P3QM5m3U, 0, m, &cVar_P3QM5m3U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_4LD6uEUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_SkCgn2S6, HV_BINOP_NEQ, 1, m, &cBinop_SkCgn2S6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_P3QM5m3U, 1, m, &cVar_P3QM5m3U_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_SkCgn2S6, HV_BINOP_NEQ, 1, m, &cBinop_SkCgn2S6_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_P3QM5m3U, 1, m, &cVar_P3QM5m3U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_P3QM5m3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WuJh1ZlH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_cffhYxMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4kQZRCE9_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LIrqEEWW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_LIrqEEWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P3QM5m3U, 0, m, &cVar_P3QM5m3U_sendMessage);
}

void Heavy_vSwell::cCast_4kQZRCE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SkCgn2S6, HV_BINOP_NEQ, 1, m, &cBinop_SkCgn2S6_sendMessage);
}

void Heavy_vSwell::cBinop_SkCgn2S6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cffhYxMg, 1, m, &cIf_cffhYxMg_sendMessage);
}

void Heavy_vSwell::cCast_rjDrclvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SkCgn2S6, HV_BINOP_NEQ, 0, m, &cBinop_SkCgn2S6_sendMessage);
}

void Heavy_vSwell::cCast_FW0Nnspj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cffhYxMg, 0, m, &cIf_cffhYxMg_sendMessage);
}

void Heavy_vSwell::cSwitchcase_pm1FM6Al_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rTMcVFyX, 0, m, &cSlice_rTMcVFyX_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MgDjxtbC, 0, m, &cSlice_MgDjxtbC_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BnuWMbMB_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Se5WcPyI_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_rTMcVFyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_hcFuA2kT, 0, m, &cVar_hcFuA2kT_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hcFuA2kT, 0, m, &cVar_hcFuA2kT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_MgDjxtbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jO6KZGhD, HV_BINOP_NEQ, 1, m, &cBinop_jO6KZGhD_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_hcFuA2kT, 1, m, &cVar_hcFuA2kT_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jO6KZGhD, HV_BINOP_NEQ, 1, m, &cBinop_jO6KZGhD_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_hcFuA2kT, 1, m, &cVar_hcFuA2kT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_hcFuA2kT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w2ChYHho_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_U3SRMSXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nmv22S3l_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_38Dh7UaS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_Nmv22S3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jO6KZGhD, HV_BINOP_NEQ, 1, m, &cBinop_jO6KZGhD_sendMessage);
}

void Heavy_vSwell::cCast_38Dh7UaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hcFuA2kT, 0, m, &cVar_hcFuA2kT_sendMessage);
}

void Heavy_vSwell::cBinop_jO6KZGhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U3SRMSXU, 1, m, &cIf_U3SRMSXU_sendMessage);
}

void Heavy_vSwell::cCast_Se5WcPyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U3SRMSXU, 0, m, &cIf_U3SRMSXU_sendMessage);
}

void Heavy_vSwell::cCast_BnuWMbMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jO6KZGhD, HV_BINOP_NEQ, 0, m, &cBinop_jO6KZGhD_sendMessage);
}

void Heavy_vSwell::cSwitchcase_WuJh1ZlH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zMOlaTAQ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdBstWMG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_zMOlaTAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wz4ydtnF, 0, m, &cVar_wz4ydtnF_sendMessage);
}

void Heavy_vSwell::cCast_JdBstWMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gsq2PK9w_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_I71ZpUXT, 0, m, &cIf_I71ZpUXT_sendMessage);
}

void Heavy_vSwell::cSwitchcase_w2ChYHho_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eGsYgQ6k_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xourSVwG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_eGsYgQ6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bc9ex0y5, 0, m, &cVar_Bc9ex0y5_sendMessage);
}

void Heavy_vSwell::cCast_xourSVwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AIvNPhCx_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_Bc9ex0y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9cqsAl4H, HV_BINOP_GREATER_THAN, 1, m, &cBinop_9cqsAl4H_sendMessage);
}

void Heavy_vSwell::cVar_wz4ydtnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vqjdRYmT, HV_BINOP_LESS_THAN, 1, m, &cBinop_vqjdRYmT_sendMessage);
}

void Heavy_vSwell::cBinop_9cqsAl4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_y6ulEIhF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_vqjdRYmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pm1FM6Al_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_Gsq2PK9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9cqsAl4H, HV_BINOP_GREATER_THAN, 1, m, &cBinop_9cqsAl4H_sendMessage);
}

void Heavy_vSwell::cMsg_AIvNPhCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vqjdRYmT, HV_BINOP_LESS_THAN, 1, m, &cBinop_vqjdRYmT_sendMessage);
}

void Heavy_vSwell::cSlice_KYchHO4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sIkybK4l_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_gWP8fYSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_lUXh9sq0, 0, m, &cIf_lUXh9sq0_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_XR1JivBu, 0, m, &cIf_XR1JivBu_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_qzsYUl8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_aGchclBH, 0, m, &cIf_aGchclBH_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_ubOExjmB, 0, m, &cIf_ubOExjmB_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_1tO9vWgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sD9gBjqU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Q938XZQb, 0, m, &cIf_Q938XZQb_sendMessage);
}

void Heavy_vSwell::cUnop_Z8Nf6N56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6DKrwuhN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yw2ghEXg, HV_BINOP_EQ, 1, m, &cBinop_yw2ghEXg_sendMessage);
}

void Heavy_vSwell::cUnop_KcvLj3eN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6DKrwuhN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yw2ghEXg, HV_BINOP_EQ, 1, m, &cBinop_yw2ghEXg_sendMessage);
}

void Heavy_vSwell::cIf_Q938XZQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_KcvLj3eN_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_Z8Nf6N56_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_sD9gBjqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q938XZQb, 1, m, &cIf_Q938XZQb_sendMessage);
}

void Heavy_vSwell::cIf_XR1JivBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rBvPtM5g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_ubOExjmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_lUXh9sq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rBvPtM5g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_aGchclBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_sIkybK4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yw2ghEXg, HV_BINOP_EQ, 0, m, &cBinop_yw2ghEXg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_f4LbAxM5_sendMessage);
}

void Heavy_vSwell::cBinop_6DKrwuhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7BDl1yR6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pf50YG1U_sendMessage);
}

void Heavy_vSwell::cBinop_yw2ghEXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l8ZHoeyv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3PAYF8Ur_sendMessage);
}

void Heavy_vSwell::cCast_3PAYF8Ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aGchclBH, 1, m, &cIf_aGchclBH_sendMessage);
}

void Heavy_vSwell::cCast_l8ZHoeyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XR1JivBu, 1, m, &cIf_XR1JivBu_sendMessage);
}

void Heavy_vSwell::cCast_pf50YG1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ubOExjmB, 1, m, &cIf_ubOExjmB_sendMessage);
}

void Heavy_vSwell::cCast_7BDl1yR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lUXh9sq0, 1, m, &cIf_lUXh9sq0_sendMessage);
}

void Heavy_vSwell::cBinop_f4LbAxM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_1VfZrgM3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZC2cMiun_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZC2cMiun_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DsTGSJMj, 1, m, &cDelay_DsTGSJMj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ec521FrP_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_DsTGSJMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DsTGSJMj, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XyZRQxk4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uTS7lUYe_sendMessage);
  cSwitchcase_rhozm7KG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ZC2cMiun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DsTGSJMj, 0, m, &cDelay_DsTGSJMj_sendMessage);
}

void Heavy_vSwell::cCast_ec521FrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DsTGSJMj, 0, m, &cDelay_DsTGSJMj_sendMessage);
}

void Heavy_vSwell::cPack_U47tYTWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zvfkhw5I_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_682Dtp0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JRf5CuNQ_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_W23HIpsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_1VfZrgM3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_TFztoGmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_U47tYTWL, 0, m, &cPack_U47tYTWL_sendMessage);
}

void Heavy_vSwell::cCast_fpdCMbTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_682Dtp0l, 0, m, &cVar_682Dtp0l_sendMessage);
}

void Heavy_vSwell::cMsg_JRf5CuNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebn0cJiy, 0, m, NULL);
}

void Heavy_vSwell::cMsg_zvfkhw5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebn0cJiy, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_rhozm7KG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_twqZiiBz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_twqZiiBz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JpnZ19Zl, 1, m, &cDelay_JpnZ19Zl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vW95Jk5I_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_JpnZ19Zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JpnZ19Zl, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R7Nt9pRD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rktUhT2F_sendMessage);
  cSwitchcase_v8VHijR5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_twqZiiBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JpnZ19Zl, 0, m, &cDelay_JpnZ19Zl_sendMessage);
}

void Heavy_vSwell::cCast_vW95Jk5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JpnZ19Zl, 0, m, &cDelay_JpnZ19Zl_sendMessage);
}

void Heavy_vSwell::cPack_se3o1lKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iV8BmorL_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_9OZhzm7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nNr69p4Z_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_osLV7nU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_rhozm7KG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_XyZRQxk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9OZhzm7n, 0, m, &cVar_9OZhzm7n_sendMessage);
}

void Heavy_vSwell::cCast_uTS7lUYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_se3o1lKo, 0, m, &cPack_se3o1lKo_sendMessage);
}

void Heavy_vSwell::cMsg_nNr69p4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebn0cJiy, 0, m, NULL);
}

void Heavy_vSwell::cMsg_iV8BmorL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebn0cJiy, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_v8VHijR5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ui385NVr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ui385NVr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UhcUutbQ, 1, m, &cDelay_UhcUutbQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M4gBpZvT_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_UhcUutbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UhcUutbQ, m);
}

void Heavy_vSwell::cMsg_Ui385NVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhcUutbQ, 0, m, &cDelay_UhcUutbQ_sendMessage);
}

void Heavy_vSwell::cCast_M4gBpZvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhcUutbQ, 0, m, &cDelay_UhcUutbQ_sendMessage);
}

void Heavy_vSwell::cPack_ocux1CLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B20n0AqO_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_MfTxJU1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bjlGhD7w_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_HZdos86p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_v8VHijR5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_rktUhT2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ocux1CLv, 0, m, &cPack_ocux1CLv_sendMessage);
}

void Heavy_vSwell::cCast_R7Nt9pRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MfTxJU1o, 0, m, &cVar_MfTxJU1o_sendMessage);
}

void Heavy_vSwell::cMsg_bjlGhD7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebn0cJiy, 0, m, NULL);
}

void Heavy_vSwell::cMsg_B20n0AqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebn0cJiy, 0, m, NULL);
}

void Heavy_vSwell::cIf_I71ZpUXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0rF7A95_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eC8HeH3i_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_DFDuyRzF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fJETW4Av_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_fJETW4Av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0rF7A95_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eC8HeH3i_sendMessage);
}

void Heavy_vSwell::cVar_BapuIkQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6btDHCit_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_VbT7TKCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ocux1CLv, 1, m, &cPack_ocux1CLv_sendMessage);
}

void Heavy_vSwell::cMsg_15tbZ7Ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UPLQob46_sendMessage);
}

void Heavy_vSwell::cSystem_UPLQob46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bPdd3BNc, HV_BINOP_MULTIPLY, 1, m, &cBinop_bPdd3BNc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DuUTXOoH, HV_BINOP_MULTIPLY, 1, m, &cBinop_DuUTXOoH_sendMessage);
}

void Heavy_vSwell::cSwitchcase_8ZTTuHAL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_lQ6YqN8J_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_lQ6YqN8J_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OSMcScx0_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_TlcGmXaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TlcGmXaQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TlcGmXaQ, 0, m, &cDelay_TlcGmXaQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ua2EOOcC, 0, m, &cVar_Ua2EOOcC_sendMessage);
}

void Heavy_vSwell::cCast_OSMcScx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lQ6YqN8J_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TlcGmXaQ, 0, m, &cDelay_TlcGmXaQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ua2EOOcC, 0, m, &cVar_Ua2EOOcC_sendMessage);
}

void Heavy_vSwell::cMsg_GtjmtSLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5fIygptF_sendMessage);
}

void Heavy_vSwell::cSystem_5fIygptF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_K5thrxIr_sendMessage);
}

void Heavy_vSwell::cVar_K2lg5SuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bYfDTb2M, HV_BINOP_MULTIPLY, 0, m, &cBinop_bYfDTb2M_sendMessage);
}

void Heavy_vSwell::cMsg_lQ6YqN8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TlcGmXaQ, 0, m, &cDelay_TlcGmXaQ_sendMessage);
}

void Heavy_vSwell::cBinop_xh32NJhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TlcGmXaQ, 2, m, &cDelay_TlcGmXaQ_sendMessage);
}

void Heavy_vSwell::cBinop_K5thrxIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bYfDTb2M, HV_BINOP_MULTIPLY, 1, m, &cBinop_bYfDTb2M_sendMessage);
}

void Heavy_vSwell::cBinop_bYfDTb2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_xh32NJhj_sendMessage);
}

void Heavy_vSwell::cVar_Ua2EOOcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpejE30G, HV_BINOP_SUBTRACT, 0, m, &cBinop_VpejE30G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_XE8yDORc_sendMessage);
}

void Heavy_vSwell::cSwitchcase_o0tylBvU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QUremvtf_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rOIR2Mtw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_QUremvtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bZTNR3et, 0, m, &cVar_bZTNR3et_sendMessage);
}

void Heavy_vSwell::cCast_rOIR2Mtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sYQrG43b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DUSSQXLq_sendMessage);
}

void Heavy_vSwell::cSwitchcase_zyXW26qq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B7zgN17Z, 0, m, &cSlice_B7zgN17Z_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fvi2UNdR, 0, m, &cSlice_fvi2UNdR_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o1W9B6TQ_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_HBpFMKwN, 0, m, &cSlice_HBpFMKwN_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_WEdTTQne, 0, m, &cSlice_WEdTTQne_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FMf0maWQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HHdtvKH4_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_B7zgN17Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_PuUQNqhM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_PuUQNqhM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_fvi2UNdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PiiEXr4u_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7j8vGQUa_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PiiEXr4u_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7j8vGQUa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_DEtWgxTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2QEdLsCO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9wh0v0F_sendMessage);
}

void Heavy_vSwell::cVar_CwYLi1yh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_65Ivt7Mn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_65Ivt7Mn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fuYg3SyJ_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bPdd3BNc, HV_BINOP_MULTIPLY, 0, m, &cBinop_bPdd3BNc_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_TAc8Ku27, HV_BINOP_DIVIDE, 1, m, &cBinop_TAc8Ku27_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_K2lg5SuR, 0, m, &cVar_K2lg5SuR_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_fuYg3SyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CqOfm5Zw_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_AF2c04EU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfgAFJCW, HV_BINOP_SUBTRACT, 1, m, &cBinop_dfgAFJCW_sendMessage);
}

void Heavy_vSwell::cVar_afr4xrUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bZTNR3et, 0, m, &cVar_bZTNR3et_sendMessage);
}

void Heavy_vSwell::cVar_bZTNR3et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oF5rlLfQ, HV_BINOP_ADD, 0, m, &cBinop_oF5rlLfQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O84zO5Zo, HV_BINOP_ADD, 0, m, &cBinop_O84zO5Zo_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PkprEZIW, m);
}

void Heavy_vSwell::cSlice_HBpFMKwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2QEdLsCO_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9wh0v0F_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_WEdTTQne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rlAMSFd5_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bLdmvvyy_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_43qDeJs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ua2EOOcC, 1, m, &cVar_Ua2EOOcC_sendMessage);
}

void Heavy_vSwell::cBinop_DuUTXOoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_43qDeJs3_sendMessage);
}

void Heavy_vSwell::cBinop_bPdd3BNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2m0PxdZA_sendMessage);
}

void Heavy_vSwell::cBinop_2m0PxdZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpejE30G, HV_BINOP_SUBTRACT, 1, m, &cBinop_VpejE30G_sendMessage);
}

void Heavy_vSwell::cBinop_VpejE30G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ua2EOOcC, 1, m, &cVar_Ua2EOOcC_sendMessage);
}

void Heavy_vSwell::cMsg_E6kLtyhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_8ZTTuHAL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_rgIcOVOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_8ZTTuHAL_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O84zO5Zo, HV_BINOP_ADD, 1, m, &cBinop_O84zO5Zo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oF5rlLfQ, HV_BINOP_ADD, 1, m, &cBinop_oF5rlLfQ_sendMessage);
}

void Heavy_vSwell::cBinop_XE8yDORc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_o0tylBvU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_oF5rlLfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bZTNR3et, 1, m, &cVar_bZTNR3et_sendMessage);
}

void Heavy_vSwell::cBinop_TAc8Ku27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ORcr7vXa, HV_BINOP_DIVIDE, 1, m, &cBinop_ORcr7vXa_sendMessage);
}

void Heavy_vSwell::cBinop_ORcr7vXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O84zO5Zo, HV_BINOP_ADD, 1, m, &cBinop_O84zO5Zo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oF5rlLfQ, HV_BINOP_ADD, 1, m, &cBinop_oF5rlLfQ_sendMessage);
}

void Heavy_vSwell::cCast_X9wh0v0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TAc8Ku27, HV_BINOP_DIVIDE, 0, m, &cBinop_TAc8Ku27_sendMessage);
}

void Heavy_vSwell::cCast_2QEdLsCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DuUTXOoH, HV_BINOP_MULTIPLY, 0, m, &cBinop_DuUTXOoH_sendMessage);
}

void Heavy_vSwell::cCast_bLdmvvyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfgAFJCW, HV_BINOP_SUBTRACT, 0, m, &cBinop_dfgAFJCW_sendMessage);
}

void Heavy_vSwell::cCast_rlAMSFd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_afr4xrUK, 1, m, &cVar_afr4xrUK_sendMessage);
}

void Heavy_vSwell::cCast_sYQrG43b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rgIcOVOa_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_DUSSQXLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_afr4xrUK, 0, m, &cVar_afr4xrUK_sendMessage);
}

void Heavy_vSwell::cBinop_O84zO5Zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AF2c04EU, 0, m, &cVar_AF2c04EU_sendMessage);
}

void Heavy_vSwell::cMsg_PuUQNqhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_8ZTTuHAL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ifK3yxkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_DEtWgxTW, 1, m, &cVar_DEtWgxTW_sendMessage);
}

void Heavy_vSwell::cMsg_CqOfm5Zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bPdd3BNc, HV_BINOP_MULTIPLY, 0, m, &cBinop_bPdd3BNc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TAc8Ku27, HV_BINOP_DIVIDE, 1, m, &cBinop_TAc8Ku27_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K2lg5SuR, 0, m, &cVar_K2lg5SuR_sendMessage);
}

void Heavy_vSwell::cCast_PiiEXr4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PuUQNqhM_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_7j8vGQUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HwpSv1zq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O84zO5Zo, HV_BINOP_ADD, 0, m, &cBinop_O84zO5Zo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bZTNR3et, 1, m, &cVar_bZTNR3et_sendMessage);
}

void Heavy_vSwell::cBinop_dfgAFJCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ORcr7vXa, HV_BINOP_DIVIDE, 0, m, &cBinop_ORcr7vXa_sendMessage);
}

void Heavy_vSwell::cCast_HwpSv1zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rgIcOVOa_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_HHdtvKH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ifK3yxkK_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_FMf0maWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E6kLtyhh_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_o1W9B6TQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DEtWgxTW, 0, m, &cVar_DEtWgxTW_sendMessage);
}

void Heavy_vSwell::cSwitchcase_iDkoFcTa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6cmkZXxb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6cmkZXxb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_G5QlZCON, 1, m, &cDelay_G5QlZCON_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oqFXE1PL_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_G5QlZCON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G5QlZCON, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fpdCMbTQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TFztoGmT_sendMessage);
  cSwitchcase_1VfZrgM3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_6cmkZXxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_G5QlZCON, 0, m, &cDelay_G5QlZCON_sendMessage);
}

void Heavy_vSwell::cCast_oqFXE1PL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G5QlZCON, 0, m, &cDelay_G5QlZCON_sendMessage);
}

void Heavy_vSwell::cVar_T08qFyEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r8Bxi70t, HV_BINOP_MULTIPLY, 0, m, &cBinop_r8Bxi70t_sendMessage);
}

void Heavy_vSwell::cMsg_OaVNLHwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zZeDy6G8_sendMessage);
}

void Heavy_vSwell::cSystem_zZeDy6G8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9laRG1sB_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_r8Bxi70t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JBxeM3B0_sendMessage);
}

void Heavy_vSwell::cBinop_giMliYDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r8Bxi70t, HV_BINOP_MULTIPLY, 1, m, &cBinop_r8Bxi70t_sendMessage);
}

void Heavy_vSwell::cMsg_9laRG1sB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_giMliYDd_sendMessage);
}

void Heavy_vSwell::cBinop_JBxeM3B0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_olI6QmA4_sendMessage);
}

void Heavy_vSwell::cBinop_olI6QmA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Mux6nOzC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qjdSRMNg, m);
}

void Heavy_vSwell::cBinop_Mux6nOzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FmPbJQ6p, m);
}

void Heavy_vSwell::cMsg_ZQdSozBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qypeqi9W_sendMessage);
}

void Heavy_vSwell::cSystem_qypeqi9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qZ4mE6vf_sendMessage);
}

void Heavy_vSwell::cDelay_ogZWKMMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ogZWKMMu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nPmFBmkJ, 0, m, &cDelay_nPmFBmkJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ogZWKMMu, 0, m, &cDelay_ogZWKMMu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mgWF76js, 1, m, NULL);
}

void Heavy_vSwell::cDelay_nPmFBmkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nPmFBmkJ, m);
  cMsg_MfCPUFQx_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_KB0aQ0To_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_5xWerDMm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_qvoFwnHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i2bee4gu_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_5jAlSjAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pT8ZK1Sg_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ogZWKMMu, 2, m, &cDelay_ogZWKMMu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TGKc4oTw_sendMessage);
}

void Heavy_vSwell::cMsg_i2bee4gu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5jAlSjAd, 0, m, &hTable_5jAlSjAd_sendMessage);
}

void Heavy_vSwell::cBinop_qZ4mE6vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qvoFwnHW_sendMessage);
}

void Heavy_vSwell::cMsg_MfCPUFQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5jAlSjAd, 0, m, &hTable_5jAlSjAd_sendMessage);
}

void Heavy_vSwell::cCast_TGKc4oTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ogZWKMMu, 0, m, &cDelay_ogZWKMMu_sendMessage);
}

void Heavy_vSwell::cMsg_pT8ZK1Sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_nPmFBmkJ, 2, m, &cDelay_nPmFBmkJ_sendMessage);
}

void Heavy_vSwell::cMsg_5xWerDMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mgWF76js, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_bjpPhRXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QQIuwtou, HV_BINOP_SUBTRACT, 0, m, &cBinop_QQIuwtou_sendMessage);
}

void Heavy_vSwell::cMsg_sgmApb8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IRfNXBGp_sendMessage);
}

void Heavy_vSwell::cSystem_IRfNXBGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bKRqc5ec_sendMessage);
}

void Heavy_vSwell::cVar_Az54KbzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pjOxDgqH_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_EiZPTMoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EiZPTMoY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_guFTXGDh, 0, m, &cDelay_guFTXGDh_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Z694mfXo, 0, m, &sTabread_Z694mfXo_sendMessage);
}

void Heavy_vSwell::cDelay_guFTXGDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_guFTXGDh, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Z694mfXo, 0, m, &sTabread_Z694mfXo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_guFTXGDh, 0, m, &cDelay_guFTXGDh_sendMessage);
}

void Heavy_vSwell::sTabread_Z694mfXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6CsOFCSZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_6CsOFCSZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_EM2qEhd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjsDO6P7, HV_BINOP_MAX, 0, m, &cBinop_zjsDO6P7_sendMessage);
}

void Heavy_vSwell::cBinop_bKRqc5ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EM2qEhd7, HV_BINOP_MULTIPLY, 0, m, &cBinop_EM2qEhd7_sendMessage);
}

void Heavy_vSwell::cBinop_QQIuwtou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EkasDhtd_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Z694mfXo, 0, m, &sTabread_Z694mfXo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_upfhqOIV_sendMessage);
}

void Heavy_vSwell::cSystem_xe4zjI8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6CsOFCSZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_6CsOFCSZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_guFTXGDh, 2, m, &cDelay_guFTXGDh_sendMessage);
}

void Heavy_vSwell::cMsg_pjOxDgqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xe4zjI8Z_sendMessage);
}

void Heavy_vSwell::cMsg_EkasDhtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EiZPTMoY, 0, m, &cDelay_EiZPTMoY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_guFTXGDh, 0, m, &cDelay_guFTXGDh_sendMessage);
}

void Heavy_vSwell::cMsg_8odN6cOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjsDO6P7, HV_BINOP_MAX, 1, m, &cBinop_zjsDO6P7_sendMessage);
}

void Heavy_vSwell::cBinop_zjsDO6P7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QQIuwtou, HV_BINOP_SUBTRACT, 1, m, &cBinop_QQIuwtou_sendMessage);
}

void Heavy_vSwell::cCast_upfhqOIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EiZPTMoY, 0, m, &cDelay_EiZPTMoY_sendMessage);
}

void Heavy_vSwell::cBinop_KcudC8RT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EiZPTMoY, 2, m, &cDelay_EiZPTMoY_sendMessage);
}

void Heavy_vSwell::cBinop_6CsOFCSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KcudC8RT_sendMessage);
}

void Heavy_vSwell::cCast_NnyfRCbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Az54KbzI, 0, m, &cVar_Az54KbzI_sendMessage);
  cMsg_sgmApb8Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_bjpPhRXP, 0, m, &cTabhead_bjpPhRXP_sendMessage);
}

void Heavy_vSwell::cUnop_jk7zeToa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NBkbhyJa, m);
}

void Heavy_vSwell::cCast_eC8HeH3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iDkoFcTa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_m0rF7A95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7d5hkFz0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BapuIkQf, 0, m, &cVar_BapuIkQf_sendMessage);
}

void Heavy_vSwell::cCast_OA9mYmVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R4tCFbL8, HV_BINOP_SUBTRACT, 0, m, &cBinop_R4tCFbL8_sendMessage);
}

void Heavy_vSwell::cCast_vTxiC9nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bc9ex0y5, 0, m, &cVar_Bc9ex0y5_sendMessage);
}

void Heavy_vSwell::cBinop_R4tCFbL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wz4ydtnF, 0, m, &cVar_wz4ydtnF_sendMessage);
}

void Heavy_vSwell::cSend_7d5hkFz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tXGTMRcA_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_rBvPtM5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DFDuyRzF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_4gbewqNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_zyXW26qq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_6btDHCit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebn0cJiy, 0, m, NULL);
}

void Heavy_vSwell::cSend_gwkh47Ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NpODmNVo_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_UGSNB2K8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G5QlZCON, 1, m, &cDelay_G5QlZCON_sendMessage);
}

void Heavy_vSwell::cBinop_69pUhDTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_jk7zeToa_sendMessage);
}

void Heavy_vSwell::cReceive_yjn0qvhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R4tCFbL8, HV_BINOP_SUBTRACT, 1, m, &cBinop_R4tCFbL8_sendMessage);
}

void Heavy_vSwell::cReceive_VYGcRkXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GtjmtSLa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_K2lg5SuR, 0, m, &cVar_K2lg5SuR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1tO9vWgI, 0, m, &cVar_1tO9vWgI_sendMessage);
  cMsg_15tbZ7Ne_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AF2c04EU, 0, m, &cVar_AF2c04EU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CwYLi1yh, 0, m, &cVar_CwYLi1yh_sendMessage);
  cMsg_OaVNLHwR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_T08qFyEm, 0, m, &cVar_T08qFyEm_sendMessage);
  cMsg_ZQdSozBg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VbT7TKCL, 0, m, &cVar_VbT7TKCL_sendMessage);
  cMsg_8odN6cOn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Az54KbzI, 0, m, &cVar_Az54KbzI_sendMessage);
  cMsg_sgmApb8Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_bjpPhRXP, 0, m, &cTabhead_bjpPhRXP_sendMessage);
}

void Heavy_vSwell::cReceive_5bVdkE0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_KYchHO4J, 0, m, &cSlice_KYchHO4J_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_gWP8fYSq, 0, m, &cSlice_gWP8fYSq_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_qzsYUl8C, 0, m, &cSlice_qzsYUl8C_sendMessage);
}

void Heavy_vSwell::cReceive_bJ6xeIBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ri7Cn2u5, m);
}

void Heavy_vSwell::cReceive_tXGTMRcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W23HIpsg_sendMessage(_c, 0, m);
  cMsg_osLV7nU5_sendMessage(_c, 0, m);
  cMsg_HZdos86p_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_gmI8uJSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OA9mYmVO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vTxiC9nw_sendMessage);
}

void Heavy_vSwell::cReceive_uRbITAPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0rF7A95_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eC8HeH3i_sendMessage);
}

void Heavy_vSwell::cReceive_ekF8Yfdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I71ZpUXT, 1, m, &cIf_I71ZpUXT_sendMessage);
}

void Heavy_vSwell::cReceive_FJaHOunS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9OZhzm7n, 1, m, &cVar_9OZhzm7n_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_U47tYTWL, 1, m, &cPack_U47tYTWL_sendMessage);
}

void Heavy_vSwell::cReceive_Sdf4QKvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_U47tYTWL, 2, m, &cPack_U47tYTWL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DsTGSJMj, 1, m, &cDelay_DsTGSJMj_sendMessage);
}

void Heavy_vSwell::cReceive_IW1LDMUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_se3o1lKo, 1, m, &cPack_se3o1lKo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MfTxJU1o, 1, m, &cVar_MfTxJU1o_sendMessage);
}

void Heavy_vSwell::cReceive_k5eQtnuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_se3o1lKo, 2, m, &cPack_se3o1lKo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JpnZ19Zl, 1, m, &cDelay_JpnZ19Zl_sendMessage);
}

void Heavy_vSwell::cReceive_eUTPiA0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ocux1CLv, 2, m, &cPack_ocux1CLv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhcUutbQ, 1, m, &cDelay_UhcUutbQ_sendMessage);
}

void Heavy_vSwell::cReceive_NpODmNVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VbT7TKCL, 1, m, &cVar_VbT7TKCL_sendMessage);
  cMsg_4gbewqNR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BapuIkQf, 1, m, &cVar_BapuIkQf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_682Dtp0l, 1, m, &cVar_682Dtp0l_sendMessage);
}

void Heavy_vSwell::cReceive_r1CI0odu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gwkh47Ss_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_7XecWmJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_UGSNB2K8_sendMessage);
}

void Heavy_vSwell::cReceive_32HpZLYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_69pUhDTS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qZvVEHEV, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_mgWF76js, VIf(I0));
    __hv_tabread_f(&sTabread_Z694mfXo, VOf(Bf0));
    __hv_varread_f(&sVarf_qjdSRMNg, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_FmPbJQ6p, VOf(Bf2));
    __hv_rpole_f(&sRPole_vHsC0qoq, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_qZvVEHEV, VOf(Bf1));
    __hv_varread_f(&sVarf_NBkbhyJa, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_EDBy3fn0, VIf(Bf3), &sEnv_EDBy3fn0_sendMessage);
    __hv_line_f(&sLine_Ebn0cJiy, VOf(Bf3));
    __hv_varread_f(&sVarf_ri7Cn2u5, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_PkprEZIW, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
