/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalTabwrite.h"
#include "HvSignalLine.h"
#include "HvControlTabhead.h"
#include "HvSignalEnvelope.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvSignalDel1.h"
#include "HvControlBinop.h"
#include "HvControlSlice.h"
#include "HvTable.h"
#include "HvControlUnop.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvSignalTabread.h"
#include "HvControlPack.h"
#include "HvMath.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_EDBy3fn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_y6ulEIhF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_OYtzs8Ia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_4LD6uEUb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P3QM5m3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cffhYxMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LIrqEEWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4kQZRCE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SkCgn2S6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rjDrclvc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FW0Nnspj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pm1FM6Al_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_rTMcVFyX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_MgDjxtbC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hcFuA2kT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_U3SRMSXU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Nmv22S3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_38Dh7UaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jO6KZGhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Se5WcPyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BnuWMbMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WuJh1ZlH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_zMOlaTAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JdBstWMG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_w2ChYHho_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_eGsYgQ6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xourSVwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Bc9ex0y5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wz4ydtnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9cqsAl4H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vqjdRYmT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gsq2PK9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AIvNPhCx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_KYchHO4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_gWP8fYSq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_qzsYUl8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1tO9vWgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Z8Nf6N56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KcvLj3eN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Q938XZQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sD9gBjqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XR1JivBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ubOExjmB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lUXh9sq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aGchclBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sIkybK4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6DKrwuhN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yw2ghEXg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3PAYF8Ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l8ZHoeyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pf50YG1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7BDl1yR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f4LbAxM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1VfZrgM3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_DsTGSJMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZC2cMiun_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ec521FrP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_U47tYTWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_682Dtp0l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W23HIpsg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TFztoGmT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fpdCMbTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JRf5CuNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zvfkhw5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rhozm7KG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JpnZ19Zl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_twqZiiBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vW95Jk5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_se3o1lKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9OZhzm7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_osLV7nU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XyZRQxk4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uTS7lUYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nNr69p4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iV8BmorL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v8VHijR5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_UhcUutbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ui385NVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M4gBpZvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ocux1CLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MfTxJU1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HZdos86p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rktUhT2F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R7Nt9pRD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bjlGhD7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B20n0AqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_I71ZpUXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DFDuyRzF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_fJETW4Av_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BapuIkQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VbT7TKCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_15tbZ7Ne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UPLQob46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8ZTTuHAL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_TlcGmXaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OSMcScx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GtjmtSLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5fIygptF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K2lg5SuR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lQ6YqN8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xh32NJhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K5thrxIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bYfDTb2M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ua2EOOcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_o0tylBvU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_QUremvtf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rOIR2Mtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zyXW26qq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_B7zgN17Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_fvi2UNdR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DEtWgxTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CwYLi1yh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_65Ivt7Mn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_fuYg3SyJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AF2c04EU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_afr4xrUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bZTNR3et_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_HBpFMKwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_WEdTTQne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_43qDeJs3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DuUTXOoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bPdd3BNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2m0PxdZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VpejE30G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E6kLtyhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rgIcOVOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XE8yDORc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oF5rlLfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TAc8Ku27_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ORcr7vXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X9wh0v0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2QEdLsCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bLdmvvyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rlAMSFd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sYQrG43b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DUSSQXLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O84zO5Zo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PuUQNqhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ifK3yxkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CqOfm5Zw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PiiEXr4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7j8vGQUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dfgAFJCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HwpSv1zq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HHdtvKH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FMf0maWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o1W9B6TQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iDkoFcTa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_G5QlZCON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6cmkZXxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oqFXE1PL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T08qFyEm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OaVNLHwR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zZeDy6G8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r8Bxi70t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_giMliYDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9laRG1sB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JBxeM3B0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_olI6QmA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mux6nOzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZQdSozBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qypeqi9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ogZWKMMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nPmFBmkJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KB0aQ0To_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_qvoFwnHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5jAlSjAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i2bee4gu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZ4mE6vf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MfCPUFQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TGKc4oTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pT8ZK1Sg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5xWerDMm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_bjpPhRXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sgmApb8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IRfNXBGp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Az54KbzI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EiZPTMoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_guFTXGDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Z694mfXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EM2qEhd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bKRqc5ec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QQIuwtou_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xe4zjI8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pjOxDgqH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EkasDhtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8odN6cOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zjsDO6P7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_upfhqOIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KcudC8RT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6CsOFCSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NnyfRCbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jk7zeToa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eC8HeH3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m0rF7A95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OA9mYmVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vTxiC9nw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R4tCFbL8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7d5hkFz0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rBvPtM5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4gbewqNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6btDHCit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gwkh47Ss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UGSNB2K8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_69pUhDTS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yjn0qvhH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VYGcRkXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5bVdkE0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bJ6xeIBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tXGTMRcA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gmI8uJSz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uRbITAPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ekF8Yfdm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FJaHOunS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Sdf4QKvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IW1LDMUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k5eQtnuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eUTPiA0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NpODmNVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r1CI0odu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7XecWmJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_32HpZLYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_mgWF76js;
  SignalTabread sTabread_Z694mfXo;
  SignalRPole sRPole_vHsC0qoq;
  SignalEnvelope sEnv_EDBy3fn0;
  SignalLine sLine_Ebn0cJiy;
  ControlSlice cSlice_OYtzs8Ia;
  ControlSlice cSlice_4LD6uEUb;
  ControlVar cVar_P3QM5m3U;
  ControlIf cIf_cffhYxMg;
  ControlBinop cBinop_SkCgn2S6;
  ControlSlice cSlice_rTMcVFyX;
  ControlSlice cSlice_MgDjxtbC;
  ControlVar cVar_hcFuA2kT;
  ControlIf cIf_U3SRMSXU;
  ControlBinop cBinop_jO6KZGhD;
  ControlVar cVar_Bc9ex0y5;
  ControlVar cVar_wz4ydtnF;
  ControlBinop cBinop_9cqsAl4H;
  ControlBinop cBinop_vqjdRYmT;
  ControlSlice cSlice_KYchHO4J;
  ControlSlice cSlice_gWP8fYSq;
  ControlSlice cSlice_qzsYUl8C;
  ControlVar cVar_1tO9vWgI;
  ControlIf cIf_Q938XZQb;
  ControlBinop cBinop_sD9gBjqU;
  ControlIf cIf_XR1JivBu;
  ControlIf cIf_ubOExjmB;
  ControlIf cIf_lUXh9sq0;
  ControlIf cIf_aGchclBH;
  ControlBinop cBinop_sIkybK4l;
  ControlBinop cBinop_6DKrwuhN;
  ControlBinop cBinop_yw2ghEXg;
  ControlBinop cBinop_f4LbAxM5;
  ControlDelay cDelay_DsTGSJMj;
  ControlPack cPack_U47tYTWL;
  ControlVar cVar_682Dtp0l;
  ControlDelay cDelay_JpnZ19Zl;
  ControlPack cPack_se3o1lKo;
  ControlVar cVar_9OZhzm7n;
  ControlDelay cDelay_UhcUutbQ;
  ControlPack cPack_ocux1CLv;
  ControlVar cVar_MfTxJU1o;
  ControlIf cIf_I71ZpUXT;
  ControlVar cVar_BapuIkQf;
  ControlVar cVar_VbT7TKCL;
  SignalVarf sVarf_PkprEZIW;
  ControlDelay cDelay_TlcGmXaQ;
  ControlVar cVar_K2lg5SuR;
  ControlBinop cBinop_xh32NJhj;
  ControlBinop cBinop_K5thrxIr;
  ControlBinop cBinop_bYfDTb2M;
  ControlVar cVar_Ua2EOOcC;
  ControlSlice cSlice_B7zgN17Z;
  ControlSlice cSlice_fvi2UNdR;
  ControlVar cVar_DEtWgxTW;
  ControlVar cVar_CwYLi1yh;
  ControlVar cVar_AF2c04EU;
  ControlVar cVar_afr4xrUK;
  ControlVar cVar_bZTNR3et;
  ControlSlice cSlice_HBpFMKwN;
  ControlSlice cSlice_WEdTTQne;
  ControlBinop cBinop_43qDeJs3;
  ControlBinop cBinop_DuUTXOoH;
  ControlBinop cBinop_bPdd3BNc;
  ControlBinop cBinop_2m0PxdZA;
  ControlBinop cBinop_VpejE30G;
  ControlBinop cBinop_XE8yDORc;
  ControlBinop cBinop_oF5rlLfQ;
  ControlBinop cBinop_TAc8Ku27;
  ControlBinop cBinop_ORcr7vXa;
  ControlBinop cBinop_O84zO5Zo;
  ControlBinop cBinop_dfgAFJCW;
  ControlDelay cDelay_G5QlZCON;
  ControlVar cVar_T08qFyEm;
  ControlBinop cBinop_r8Bxi70t;
  ControlBinop cBinop_giMliYDd;
  SignalVarf sVarf_FmPbJQ6p;
  ControlBinop cBinop_JBxeM3B0;
  ControlBinop cBinop_olI6QmA4;
  ControlBinop cBinop_Mux6nOzC;
  SignalVarf sVarf_qjdSRMNg;
  ControlDelay cDelay_ogZWKMMu;
  ControlDelay cDelay_nPmFBmkJ;
  ControlBinop cBinop_qvoFwnHW;
  HvTable hTable_5jAlSjAd;
  ControlBinop cBinop_qZ4mE6vf;
  ControlTabhead cTabhead_bjpPhRXP;
  ControlVar cVar_Az54KbzI;
  ControlDelay cDelay_EiZPTMoY;
  ControlDelay cDelay_guFTXGDh;
  ControlBinop cBinop_EM2qEhd7;
  ControlBinop cBinop_bKRqc5ec;
  ControlBinop cBinop_QQIuwtou;
  ControlBinop cBinop_zjsDO6P7;
  ControlBinop cBinop_KcudC8RT;
  ControlBinop cBinop_6CsOFCSZ;
  ControlBinop cBinop_R4tCFbL8;
  ControlBinop cBinop_rBvPtM5g;
  ControlBinop cBinop_UGSNB2K8;
  ControlBinop cBinop_69pUhDTS;
  SignalVarf sVarf_ri7Cn2u5;
  SignalVarf sVarf_NBkbhyJa;
  SignalVarf sVarf_qZvVEHEV;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
