/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_W1jOcfAV, &hTable_owpVNraA);
  numBytes += sTabwrite_init(&sTabwrite_2gumaBYw, &hTable_ITwVLAKg);
  numBytes += sRPole_init(&sRPole_bKv5Gk0J);
  numBytes += sEnv_init(&sEnv_M2s9mixl, 1024, 512);
  numBytes += sTabread_init(&sTabread_8JyYJjWS, &hTable_ITwVLAKg, true);
  numBytes += sLine_init(&sLine_VULbca2O);
  numBytes += sTabread_init(&sTabread_whRWcDbe, &hTable_owpVNraA, true);
  numBytes += cSlice_init(&cSlice_NNK7DNVE, 1, -1);
  numBytes += cSlice_init(&cSlice_b4RT9Tx5, 1, -1);
  numBytes += cVar_init_f(&cVar_9NzSkhSu, 0.0f);
  numBytes += cIf_init(&cIf_x0FbXJZ5, false);
  numBytes += cBinop_init(&cBinop_tymXmwGo, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_VlSQBMvm, 1, -1);
  numBytes += cSlice_init(&cSlice_DNFxR5x9, 1, -1);
  numBytes += cVar_init_f(&cVar_lISSxcFD, 0.0f);
  numBytes += cIf_init(&cIf_VJEcHYx0, false);
  numBytes += cBinop_init(&cBinop_iI8OBJ2H, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_Vkkdb3Sl, 0.0f);
  numBytes += cVar_init_f(&cVar_OGp67hQM, 0.0f);
  numBytes += cBinop_init(&cBinop_NNrxbLtC, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_Fqw9gT9c, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_jxXY6i3f, 2, 1);
  numBytes += cSlice_init(&cSlice_xllR15dY, 1, 1);
  numBytes += cSlice_init(&cSlice_XdCKf8vJ, 0, 1);
  numBytes += cVar_init_f(&cVar_BWkirai1, 0.0f);
  numBytes += cIf_init(&cIf_ftOjA8je, false);
  numBytes += cIf_init(&cIf_ewe2roce, false);
  numBytes += cIf_init(&cIf_M2tyQ6h4, false);
  numBytes += cIf_init(&cIf_DctWN2Ye, false);
  numBytes += cIf_init(&cIf_ekEHLooc, false);
  numBytes += cBinop_init(&cBinop_bXsCdnyA, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_l3F7xEMh, 10.0f);
  numBytes += cPack_init(&cPack_lrFJAaPj, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_DIAvl0x3, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_dH9ae4wm, 10.0f);
  numBytes += cPack_init(&cPack_hfjunwSK, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_duNFfEoG, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_lro5Goof, 10.0f);
  numBytes += cPack_init(&cPack_WThK92fM, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_MHlOFzpa, 1e-07f);
  numBytes += cVar_init_f(&cVar_TlDnjcCL, 1e-07f);
  numBytes += cVar_init_f(&cVar_JVzi2aPH, 1e-07f);
  numBytes += sVarf_init(&sVarf_6st1RsKx, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_1KNTdczd, 0.0f);
  numBytes += cVar_init_f(&cVar_KNyeo9ax, 20.0f);
  numBytes += cBinop_init(&cBinop_ykIvWLSy, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_i4U0vfdc, 0.0f);
  numBytes += cSlice_init(&cSlice_cCJZJsX1, 1, -1);
  numBytes += cSlice_init(&cSlice_6c1hA2Zn, 1, -1);
  numBytes += cVar_init_f(&cVar_xYfjeBO6, 0.0f);
  numBytes += cVar_init_f(&cVar_j3ijwMRX, 20.0f);
  numBytes += cVar_init_f(&cVar_yS086Bue, 0.0f);
  numBytes += cVar_init_f(&cVar_kJ30AjI3, 0.0f);
  numBytes += cVar_init_f(&cVar_jIHyKB2N, 0.0f);
  numBytes += cSlice_init(&cSlice_Wc3CAXOQ, 1, 1);
  numBytes += cSlice_init(&cSlice_tvBQfuah, 0, 1);
  numBytes += cBinop_init(&cBinop_69V2nvnu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XQ3xWopc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9xRuStqY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9UqXl39l, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_CHcbn8aS, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_EtCwsW0v, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_kHSZTMcj, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_2o5svICQ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_E9Anmp4B, 5.0f);
  numBytes += cVar_init_f(&cVar_So0QmUCl, 500.0f);
  numBytes += cBinop_init(&cBinop_BCy1Wg9u, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_52wtZKA8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bJQv62jL, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_hJNTUCoO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_nActJnXj, 0.0f);
  numBytes += hTable_init(&hTable_owpVNraA, 256);
  numBytes += cTabhead_init(&cTabhead_IcLkf2QM, &hTable_owpVNraA);
  numBytes += cVar_init_s(&cVar_sCkMkswc, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_GL453hiE, 8.0f);
  numBytes += cDelay_init(this, &cDelay_twUnvqfI, 0.0f);
  numBytes += cBinop_init(&cBinop_ejvg5FHy, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_1OmVGleY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_mW65rXWH, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_7qiZuR7b, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_h0kkHLu8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_IRrpkm16, 0.0f);
  numBytes += hTable_init(&hTable_ITwVLAKg, 256);
  numBytes += cTabhead_init(&cTabhead_Ip7ymV5h, &hTable_ITwVLAKg);
  numBytes += cVar_init_s(&cVar_Z3p8Nmhx, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_X6Ogmiel, 8.0f);
  numBytes += cDelay_init(this, &cDelay_8RulvUad, 0.0f);
  numBytes += cBinop_init(&cBinop_x9AEwYCd, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_GtT3WQTw, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_kxWsv0vU, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_hM1oK2ty, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_0Z9vpAIQ, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_vNeFznDU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ru72wZCJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kyQsqv3r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CTHrZpGc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RHSAeQ5z, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_M2s9mixl);
  cPack_free(&cPack_lrFJAaPj);
  cPack_free(&cPack_hfjunwSK);
  cPack_free(&cPack_WThK92fM);
  hTable_free(&hTable_owpVNraA);
  hTable_free(&hTable_ITwVLAKg);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_owpVNraA; // del-1001-swell
    case 0x505A9C79: return &hTable_ITwVLAKg; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yfGrkaFQ_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gScMmfQd_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bsrvgvdc_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KtLiwKfF_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vnn56fYH_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LjrL2X8j_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GeHXTK4x_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EiGTmltp_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s9aQ1k3s_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PvJpQlN0_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_649puD0e_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A0wlJ8Bh_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oiSZxwPe_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z23rVpng_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FzcZMgL2_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jBUannWL_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GttxKX73_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aLEqVVWY_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_M2s9mixl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NNrxbLtC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_NNrxbLtC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fqw9gT9c, HV_BINOP_LESS_THAN, 0, m, &cBinop_Fqw9gT9c_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_fMTGVW5Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NNK7DNVE, 0, m, &cSlice_NNK7DNVE_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b4RT9Tx5, 0, m, &cSlice_b4RT9Tx5_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2HxzK2jJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dP83YwUe_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_NNK7DNVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_9NzSkhSu, 0, m, &cVar_9NzSkhSu_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9NzSkhSu, 0, m, &cVar_9NzSkhSu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_b4RT9Tx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_tymXmwGo, HV_BINOP_NEQ, 1, m, &cBinop_tymXmwGo_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9NzSkhSu, 1, m, &cVar_9NzSkhSu_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_tymXmwGo, HV_BINOP_NEQ, 1, m, &cBinop_tymXmwGo_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9NzSkhSu, 1, m, &cVar_9NzSkhSu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_9NzSkhSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LwIBHqxX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_x0FbXJZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x3kHS0Pg_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FYykYu0i_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_FYykYu0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9NzSkhSu, 0, m, &cVar_9NzSkhSu_sendMessage);
}

void Heavy_vSwellST::cCast_x3kHS0Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tymXmwGo, HV_BINOP_NEQ, 1, m, &cBinop_tymXmwGo_sendMessage);
}

void Heavy_vSwellST::cBinop_tymXmwGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x0FbXJZ5, 1, m, &cIf_x0FbXJZ5_sendMessage);
}

void Heavy_vSwellST::cCast_2HxzK2jJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tymXmwGo, HV_BINOP_NEQ, 0, m, &cBinop_tymXmwGo_sendMessage);
}

void Heavy_vSwellST::cCast_dP83YwUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x0FbXJZ5, 0, m, &cIf_x0FbXJZ5_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_CzEjdRuE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VlSQBMvm, 0, m, &cSlice_VlSQBMvm_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DNFxR5x9, 0, m, &cSlice_DNFxR5x9_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nq7RqoBY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oHJqs98y_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_VlSQBMvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_lISSxcFD, 0, m, &cVar_lISSxcFD_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_lISSxcFD, 0, m, &cVar_lISSxcFD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_DNFxR5x9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iI8OBJ2H, HV_BINOP_NEQ, 1, m, &cBinop_iI8OBJ2H_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_lISSxcFD, 1, m, &cVar_lISSxcFD_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iI8OBJ2H, HV_BINOP_NEQ, 1, m, &cBinop_iI8OBJ2H_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_lISSxcFD, 1, m, &cVar_lISSxcFD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_lISSxcFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SlQG0OrM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_VJEcHYx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3mC0gsAM_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YAgXoqav_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_3mC0gsAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iI8OBJ2H, HV_BINOP_NEQ, 1, m, &cBinop_iI8OBJ2H_sendMessage);
}

void Heavy_vSwellST::cCast_YAgXoqav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lISSxcFD, 0, m, &cVar_lISSxcFD_sendMessage);
}

void Heavy_vSwellST::cBinop_iI8OBJ2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VJEcHYx0, 1, m, &cIf_VJEcHYx0_sendMessage);
}

void Heavy_vSwellST::cCast_nq7RqoBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iI8OBJ2H, HV_BINOP_NEQ, 0, m, &cBinop_iI8OBJ2H_sendMessage);
}

void Heavy_vSwellST::cCast_oHJqs98y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VJEcHYx0, 0, m, &cIf_VJEcHYx0_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_LwIBHqxX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JxZeOLVE_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6OyvqgmF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_JxZeOLVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OGp67hQM, 0, m, &cVar_OGp67hQM_sendMessage);
}

void Heavy_vSwellST::cCast_6OyvqgmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0VjMGGnL_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UppGDGzX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LUSyhNlJ_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_SlQG0OrM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_feVt2vn8_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CO8sBZcc_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_feVt2vn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vkkdb3Sl, 0, m, &cVar_Vkkdb3Sl_sendMessage);
}

void Heavy_vSwellST::cCast_CO8sBZcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fB9wzvSN_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_Vkkdb3Sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NNrxbLtC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_NNrxbLtC_sendMessage);
}

void Heavy_vSwellST::cVar_OGp67hQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fqw9gT9c, HV_BINOP_LESS_THAN, 1, m, &cBinop_Fqw9gT9c_sendMessage);
}

void Heavy_vSwellST::cBinop_NNrxbLtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fMTGVW5Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_Fqw9gT9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CzEjdRuE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_0VjMGGnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NNrxbLtC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_NNrxbLtC_sendMessage);
}

void Heavy_vSwellST::cMsg_fB9wzvSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fqw9gT9c, HV_BINOP_LESS_THAN, 1, m, &cBinop_Fqw9gT9c_sendMessage);
}

void Heavy_vSwellST::cSlice_jxXY6i3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XTe1Fndb_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_xllR15dY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_DctWN2Ye, 0, m, &cIf_DctWN2Ye_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_ewe2roce, 0, m, &cIf_ewe2roce_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_XdCKf8vJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_ekEHLooc, 0, m, &cIf_ekEHLooc_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_M2tyQ6h4, 0, m, &cIf_M2tyQ6h4_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_BWkirai1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pBFeBw8Q_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ftOjA8je, 0, m, &cIf_ftOjA8je_sendMessage);
}

void Heavy_vSwellST::cUnop_pvbmh7xC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZE9DZPRh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bXsCdnyA, HV_BINOP_EQ, 1, m, &cBinop_bXsCdnyA_sendMessage);
}

void Heavy_vSwellST::cUnop_yWmRoylE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZE9DZPRh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bXsCdnyA, HV_BINOP_EQ, 1, m, &cBinop_bXsCdnyA_sendMessage);
}

void Heavy_vSwellST::cIf_ftOjA8je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_yWmRoylE_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_pvbmh7xC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_pBFeBw8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ftOjA8je, 1, m, &cIf_ftOjA8je_sendMessage);
}

void Heavy_vSwellST::cIf_ewe2roce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kSHmIXDc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_M2tyQ6h4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_DctWN2Ye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kSHmIXDc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_ekEHLooc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_XTe1Fndb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bXsCdnyA, HV_BINOP_EQ, 0, m, &cBinop_bXsCdnyA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_lgMKikgF_sendMessage);
}

void Heavy_vSwellST::cBinop_ZE9DZPRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ec7xsVws_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M1ouCamH_sendMessage);
}

void Heavy_vSwellST::cBinop_bXsCdnyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P0gjrMZx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fwsUuYMO_sendMessage);
}

void Heavy_vSwellST::cCast_fwsUuYMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ekEHLooc, 1, m, &cIf_ekEHLooc_sendMessage);
}

void Heavy_vSwellST::cCast_P0gjrMZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ewe2roce, 1, m, &cIf_ewe2roce_sendMessage);
}

void Heavy_vSwellST::cCast_M1ouCamH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M2tyQ6h4, 1, m, &cIf_M2tyQ6h4_sendMessage);
}

void Heavy_vSwellST::cCast_ec7xsVws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DctWN2Ye, 1, m, &cIf_DctWN2Ye_sendMessage);
}

void Heavy_vSwellST::cBinop_lgMKikgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_sRKLn6BT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xKJ6O2wg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xKJ6O2wg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_l3F7xEMh, 1, m, &cDelay_l3F7xEMh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LKR4WhHb_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_l3F7xEMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l3F7xEMh, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_je6twNaJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jt1FWkD8_sendMessage);
  cSwitchcase_H2NdbEFl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_xKJ6O2wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_l3F7xEMh, 0, m, &cDelay_l3F7xEMh_sendMessage);
}

void Heavy_vSwellST::cCast_LKR4WhHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_l3F7xEMh, 0, m, &cDelay_l3F7xEMh_sendMessage);
}

void Heavy_vSwellST::cPack_lrFJAaPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gcsNhQgy_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_DIAvl0x3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1V8jH1FZ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_e957BUig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_sRKLn6BT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_c1aLkXJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_lrFJAaPj, 0, m, &cPack_lrFJAaPj_sendMessage);
}

void Heavy_vSwellST::cCast_h4zfP9sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DIAvl0x3, 0, m, &cVar_DIAvl0x3_sendMessage);
}

void Heavy_vSwellST::cMsg_1V8jH1FZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_VULbca2O, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_gcsNhQgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_VULbca2O, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_H2NdbEFl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ir6lI36H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ir6lI36H_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dH9ae4wm, 1, m, &cDelay_dH9ae4wm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zdIEnMg9_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_dH9ae4wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dH9ae4wm, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dLVsJRn8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ueN9mk8_sendMessage);
  cSwitchcase_Qr2gK2zl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_Ir6lI36H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dH9ae4wm, 0, m, &cDelay_dH9ae4wm_sendMessage);
}

void Heavy_vSwellST::cCast_zdIEnMg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dH9ae4wm, 0, m, &cDelay_dH9ae4wm_sendMessage);
}

void Heavy_vSwellST::cPack_hfjunwSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJrl89Lm_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_duNFfEoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f14VtxZI_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_ceDZY6Zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_H2NdbEFl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_jt1FWkD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_hfjunwSK, 0, m, &cPack_hfjunwSK_sendMessage);
}

void Heavy_vSwellST::cCast_je6twNaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_duNFfEoG, 0, m, &cVar_duNFfEoG_sendMessage);
}

void Heavy_vSwellST::cMsg_f14VtxZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_VULbca2O, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_FJrl89Lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_VULbca2O, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_Qr2gK2zl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3dHilIdY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3dHilIdY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lro5Goof, 1, m, &cDelay_lro5Goof_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ppwDWqaR_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_lro5Goof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lro5Goof, m);
}

void Heavy_vSwellST::cMsg_3dHilIdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lro5Goof, 0, m, &cDelay_lro5Goof_sendMessage);
}

void Heavy_vSwellST::cCast_ppwDWqaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lro5Goof, 0, m, &cDelay_lro5Goof_sendMessage);
}

void Heavy_vSwellST::cPack_WThK92fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tBxHKW5g_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_MHlOFzpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GybXzbc9_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_AGPODrtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_Qr2gK2zl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_dLVsJRn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MHlOFzpa, 0, m, &cVar_MHlOFzpa_sendMessage);
}

void Heavy_vSwellST::cCast_4ueN9mk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_WThK92fM, 0, m, &cPack_WThK92fM_sendMessage);
}

void Heavy_vSwellST::cMsg_GybXzbc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_VULbca2O, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_tBxHKW5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_VULbca2O, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_ZHlIoBFf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8n58dKBA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_8n58dKBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UppGDGzX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LUSyhNlJ_sendMessage);
}

void Heavy_vSwellST::cVar_TlDnjcCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOkaBw46_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_JVzi2aPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_WThK92fM, 1, m, &cPack_WThK92fM_sendMessage);
}

void Heavy_vSwellST::cMsg_jR8WgIdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bi9Ssdo1_sendMessage);
}

void Heavy_vSwellST::cSystem_bi9Ssdo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQ3xWopc, HV_BINOP_MULTIPLY, 1, m, &cBinop_XQ3xWopc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_69V2nvnu, HV_BINOP_MULTIPLY, 1, m, &cBinop_69V2nvnu_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_4YTt0ppQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_ZETus8Yj_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_ZETus8Yj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kdEyVxzO_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_1KNTdczd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1KNTdczd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1KNTdczd, 0, m, &cDelay_1KNTdczd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i4U0vfdc, 0, m, &cVar_i4U0vfdc_sendMessage);
}

void Heavy_vSwellST::cCast_kdEyVxzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZETus8Yj_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1KNTdczd, 0, m, &cDelay_1KNTdczd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i4U0vfdc, 0, m, &cVar_i4U0vfdc_sendMessage);
}

void Heavy_vSwellST::cMsg_1j6PXEFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NFtrRFfN_sendMessage);
}

void Heavy_vSwellST::cSystem_NFtrRFfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KxLYFCKB_sendMessage);
}

void Heavy_vSwellST::cVar_KNyeo9ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ykIvWLSy, HV_BINOP_MULTIPLY, 0, m, &cBinop_ykIvWLSy_sendMessage);
}

void Heavy_vSwellST::cMsg_ZETus8Yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1KNTdczd, 0, m, &cDelay_1KNTdczd_sendMessage);
}

void Heavy_vSwellST::cBinop_5aJpk6QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1KNTdczd, 2, m, &cDelay_1KNTdczd_sendMessage);
}

void Heavy_vSwellST::cBinop_KxLYFCKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ykIvWLSy, HV_BINOP_MULTIPLY, 1, m, &cBinop_ykIvWLSy_sendMessage);
}

void Heavy_vSwellST::cBinop_ykIvWLSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5aJpk6QI_sendMessage);
}

void Heavy_vSwellST::cVar_i4U0vfdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9xRuStqY, HV_BINOP_SUBTRACT, 0, m, &cBinop_9xRuStqY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_0TzuVNEc_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_tqkbuhYT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KTyuMVeW_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jRTnBqAt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_KTyuMVeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jIHyKB2N, 0, m, &cVar_jIHyKB2N_sendMessage);
}

void Heavy_vSwellST::cCast_jRTnBqAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_80MrvIxy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ayJ1eTaj_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_akHKRZVr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cCJZJsX1, 0, m, &cSlice_cCJZJsX1_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6c1hA2Zn, 0, m, &cSlice_6c1hA2Zn_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PmO6luKd_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_Wc3CAXOQ, 0, m, &cSlice_Wc3CAXOQ_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_tvBQfuah, 0, m, &cSlice_tvBQfuah_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_23IDgafw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jiypaYcY_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_cCJZJsX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7HuCHm5i_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_7HuCHm5i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_6c1hA2Zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ubIB2vvd_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_khUvHqNF_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ubIB2vvd_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_khUvHqNF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_xYfjeBO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rswesdyA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M251m8Pb_sendMessage);
}

void Heavy_vSwellST::cVar_j3ijwMRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qF9YSxMI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_qF9YSxMI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZzFrp4EN_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XQ3xWopc, HV_BINOP_MULTIPLY, 0, m, &cBinop_XQ3xWopc_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_CHcbn8aS, HV_BINOP_DIVIDE, 1, m, &cBinop_CHcbn8aS_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_KNyeo9ax, 0, m, &cVar_KNyeo9ax_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_ZzFrp4EN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gV9AlxUt_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_yS086Bue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2o5svICQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_2o5svICQ_sendMessage);
}

void Heavy_vSwellST::cVar_kJ30AjI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jIHyKB2N, 0, m, &cVar_jIHyKB2N_sendMessage);
}

void Heavy_vSwellST::cVar_jIHyKB2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9UqXl39l, HV_BINOP_ADD, 0, m, &cBinop_9UqXl39l_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kHSZTMcj, HV_BINOP_ADD, 0, m, &cBinop_kHSZTMcj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6st1RsKx, m);
}

void Heavy_vSwellST::cSlice_Wc3CAXOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rswesdyA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M251m8Pb_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_tvBQfuah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dV4Ohg48_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6EfTnc9M_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_CZ7FqRSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i4U0vfdc, 1, m, &cVar_i4U0vfdc_sendMessage);
}

void Heavy_vSwellST::cBinop_69V2nvnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CZ7FqRSY_sendMessage);
}

void Heavy_vSwellST::cBinop_XQ3xWopc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vkbTdWRR_sendMessage);
}

void Heavy_vSwellST::cBinop_vkbTdWRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9xRuStqY, HV_BINOP_SUBTRACT, 1, m, &cBinop_9xRuStqY_sendMessage);
}

void Heavy_vSwellST::cBinop_9xRuStqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i4U0vfdc, 1, m, &cVar_i4U0vfdc_sendMessage);
}

void Heavy_vSwellST::cMsg_suvt6sHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_4YTt0ppQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_xEGDa8VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_4YTt0ppQ_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kHSZTMcj, HV_BINOP_ADD, 1, m, &cBinop_kHSZTMcj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9UqXl39l, HV_BINOP_ADD, 1, m, &cBinop_9UqXl39l_sendMessage);
}

void Heavy_vSwellST::cBinop_0TzuVNEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tqkbuhYT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_9UqXl39l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jIHyKB2N, 1, m, &cVar_jIHyKB2N_sendMessage);
}

void Heavy_vSwellST::cBinop_CHcbn8aS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EtCwsW0v, HV_BINOP_DIVIDE, 1, m, &cBinop_EtCwsW0v_sendMessage);
}

void Heavy_vSwellST::cBinop_EtCwsW0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kHSZTMcj, HV_BINOP_ADD, 1, m, &cBinop_kHSZTMcj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9UqXl39l, HV_BINOP_ADD, 1, m, &cBinop_9UqXl39l_sendMessage);
}

void Heavy_vSwellST::cCast_M251m8Pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHcbn8aS, HV_BINOP_DIVIDE, 0, m, &cBinop_CHcbn8aS_sendMessage);
}

void Heavy_vSwellST::cCast_rswesdyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_69V2nvnu, HV_BINOP_MULTIPLY, 0, m, &cBinop_69V2nvnu_sendMessage);
}

void Heavy_vSwellST::cCast_6EfTnc9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2o5svICQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_2o5svICQ_sendMessage);
}

void Heavy_vSwellST::cCast_dV4Ohg48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kJ30AjI3, 1, m, &cVar_kJ30AjI3_sendMessage);
}

void Heavy_vSwellST::cCast_ayJ1eTaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kJ30AjI3, 0, m, &cVar_kJ30AjI3_sendMessage);
}

void Heavy_vSwellST::cCast_80MrvIxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xEGDa8VM_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_kHSZTMcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yS086Bue, 0, m, &cVar_yS086Bue_sendMessage);
}

void Heavy_vSwellST::cMsg_7HuCHm5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_4YTt0ppQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_er91PCyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_xYfjeBO6, 1, m, &cVar_xYfjeBO6_sendMessage);
}

void Heavy_vSwellST::cMsg_gV9AlxUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQ3xWopc, HV_BINOP_MULTIPLY, 0, m, &cBinop_XQ3xWopc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHcbn8aS, HV_BINOP_DIVIDE, 1, m, &cBinop_CHcbn8aS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KNyeo9ax, 0, m, &cVar_KNyeo9ax_sendMessage);
}

void Heavy_vSwellST::cCast_khUvHqNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y1P1lZW3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kHSZTMcj, HV_BINOP_ADD, 0, m, &cBinop_kHSZTMcj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jIHyKB2N, 1, m, &cVar_jIHyKB2N_sendMessage);
}

void Heavy_vSwellST::cCast_ubIB2vvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7HuCHm5i_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_2o5svICQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EtCwsW0v, HV_BINOP_DIVIDE, 0, m, &cBinop_EtCwsW0v_sendMessage);
}

void Heavy_vSwellST::cCast_Y1P1lZW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xEGDa8VM_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_PmO6luKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xYfjeBO6, 0, m, &cVar_xYfjeBO6_sendMessage);
}

void Heavy_vSwellST::cCast_jiypaYcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_er91PCyl_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_23IDgafw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_suvt6sHw_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_JsIctw6J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ebPLoG1R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ebPLoG1R_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_E9Anmp4B, 1, m, &cDelay_E9Anmp4B_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DIcqsCBR_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_E9Anmp4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E9Anmp4B, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h4zfP9sW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1aLkXJE_sendMessage);
  cSwitchcase_sRKLn6BT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_ebPLoG1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_E9Anmp4B, 0, m, &cDelay_E9Anmp4B_sendMessage);
}

void Heavy_vSwellST::cCast_DIcqsCBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E9Anmp4B, 0, m, &cDelay_E9Anmp4B_sendMessage);
}

void Heavy_vSwellST::cVar_So0QmUCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BCy1Wg9u, HV_BINOP_MULTIPLY, 0, m, &cBinop_BCy1Wg9u_sendMessage);
}

void Heavy_vSwellST::cMsg_jy8cfEu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RqTZCW9p_sendMessage);
}

void Heavy_vSwellST::cSystem_RqTZCW9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AIal5Mry_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_BCy1Wg9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GKEtPH6q_sendMessage);
}

void Heavy_vSwellST::cBinop_YE8ulUuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BCy1Wg9u, HV_BINOP_MULTIPLY, 1, m, &cBinop_BCy1Wg9u_sendMessage);
}

void Heavy_vSwellST::cMsg_AIal5Mry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YE8ulUuK_sendMessage);
}

void Heavy_vSwellST::cBinop_GKEtPH6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AKNsUOdT_sendMessage);
}

void Heavy_vSwellST::cBinop_AKNsUOdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_q4mct4nl_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bJQv62jL, m);
}

void Heavy_vSwellST::cBinop_q4mct4nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_52wtZKA8, m);
}

void Heavy_vSwellST::cMsg_1eQKHN6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_52sFN3nN_sendMessage);
}

void Heavy_vSwellST::cSystem_52sFN3nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kd4wxWfi_sendMessage);
}

void Heavy_vSwellST::cDelay_hJNTUCoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hJNTUCoO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nActJnXj, 0, m, &cDelay_nActJnXj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hJNTUCoO, 0, m, &cDelay_hJNTUCoO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_W1jOcfAV, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_nActJnXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nActJnXj, m);
  cMsg_pJqUBRnp_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_tRG39Adv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ttA6VvWF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_0N9E3RAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTEzeCYX_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_owpVNraA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tVlzQ3Ol_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hJNTUCoO, 2, m, &cDelay_hJNTUCoO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ycghnqEO_sendMessage);
}

void Heavy_vSwellST::cMsg_DTEzeCYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_owpVNraA, 0, m, &hTable_owpVNraA_sendMessage);
}

void Heavy_vSwellST::cBinop_kd4wxWfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0N9E3RAr_sendMessage);
}

void Heavy_vSwellST::cMsg_pJqUBRnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_owpVNraA, 0, m, &hTable_owpVNraA_sendMessage);
}

void Heavy_vSwellST::cCast_ycghnqEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hJNTUCoO, 0, m, &cDelay_hJNTUCoO_sendMessage);
}

void Heavy_vSwellST::cMsg_tVlzQ3Ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_nActJnXj, 2, m, &cDelay_nActJnXj_sendMessage);
}

void Heavy_vSwellST::cMsg_ttA6VvWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_W1jOcfAV, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_IcLkf2QM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OmVGleY, HV_BINOP_SUBTRACT, 0, m, &cBinop_1OmVGleY_sendMessage);
}

void Heavy_vSwellST::cMsg_8zn4sdUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_d4Zl4JZd_sendMessage);
}

void Heavy_vSwellST::cSystem_d4Zl4JZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_puuCW3AF_sendMessage);
}

void Heavy_vSwellST::cVar_sCkMkswc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UPIHDGsI_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_GL453hiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GL453hiE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_twUnvqfI, 0, m, &cDelay_twUnvqfI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_whRWcDbe, 0, m, &sTabread_whRWcDbe_sendMessage);
}

void Heavy_vSwellST::cDelay_twUnvqfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_twUnvqfI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_whRWcDbe, 0, m, &sTabread_whRWcDbe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_twUnvqfI, 0, m, &cDelay_twUnvqfI_sendMessage);
}

void Heavy_vSwellST::sTabread_whRWcDbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7qiZuR7b, HV_BINOP_SUBTRACT, 0, m, &cBinop_7qiZuR7b_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_ejvg5FHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mW65rXWH, HV_BINOP_MAX, 0, m, &cBinop_mW65rXWH_sendMessage);
}

void Heavy_vSwellST::cBinop_puuCW3AF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ejvg5FHy, HV_BINOP_MULTIPLY, 0, m, &cBinop_ejvg5FHy_sendMessage);
}

void Heavy_vSwellST::cBinop_1OmVGleY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FH2FEKNz_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_whRWcDbe, 0, m, &sTabread_whRWcDbe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wB0CvQmI_sendMessage);
}

void Heavy_vSwellST::cSystem_RHAmK6uP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7qiZuR7b, HV_BINOP_SUBTRACT, 1, m, &cBinop_7qiZuR7b_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_twUnvqfI, 2, m, &cDelay_twUnvqfI_sendMessage);
}

void Heavy_vSwellST::cMsg_UPIHDGsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RHAmK6uP_sendMessage);
}

void Heavy_vSwellST::cMsg_FH2FEKNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GL453hiE, 0, m, &cDelay_GL453hiE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_twUnvqfI, 0, m, &cDelay_twUnvqfI_sendMessage);
}

void Heavy_vSwellST::cMsg_G7TPMp6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_mW65rXWH, HV_BINOP_MAX, 1, m, &cBinop_mW65rXWH_sendMessage);
}

void Heavy_vSwellST::cBinop_mW65rXWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OmVGleY, HV_BINOP_SUBTRACT, 1, m, &cBinop_1OmVGleY_sendMessage);
}

void Heavy_vSwellST::cCast_wB0CvQmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GL453hiE, 0, m, &cDelay_GL453hiE_sendMessage);
}

void Heavy_vSwellST::cBinop_aWmEPexz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GL453hiE, 2, m, &cDelay_GL453hiE_sendMessage);
}

void Heavy_vSwellST::cBinop_7qiZuR7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aWmEPexz_sendMessage);
}

void Heavy_vSwellST::cCast_ubne2k7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sCkMkswc, 0, m, &cVar_sCkMkswc_sendMessage);
  cMsg_8zn4sdUe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IcLkf2QM, 0, m, &cTabhead_IcLkf2QM_sendMessage);
}

void Heavy_vSwellST::cMsg_FrxV25mX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OOePFlgK_sendMessage);
}

void Heavy_vSwellST::cSystem_OOePFlgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VgNuLiZM_sendMessage);
}

void Heavy_vSwellST::cDelay_h0kkHLu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h0kkHLu8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IRrpkm16, 0, m, &cDelay_IRrpkm16_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0kkHLu8, 0, m, &cDelay_h0kkHLu8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2gumaBYw, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_IRrpkm16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IRrpkm16, m);
  cMsg_NskkMo39_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_LIDhcF6x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ytpe9LWB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_PHPFy9ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ECpUwdaD_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_ITwVLAKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KqgrFa94_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0kkHLu8, 2, m, &cDelay_h0kkHLu8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uLijjDT6_sendMessage);
}

void Heavy_vSwellST::cMsg_ECpUwdaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ITwVLAKg, 0, m, &hTable_ITwVLAKg_sendMessage);
}

void Heavy_vSwellST::cBinop_VgNuLiZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_PHPFy9ky_sendMessage);
}

void Heavy_vSwellST::cMsg_NskkMo39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ITwVLAKg, 0, m, &hTable_ITwVLAKg_sendMessage);
}

void Heavy_vSwellST::cCast_uLijjDT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0kkHLu8, 0, m, &cDelay_h0kkHLu8_sendMessage);
}

void Heavy_vSwellST::cMsg_KqgrFa94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_IRrpkm16, 2, m, &cDelay_IRrpkm16_sendMessage);
}

void Heavy_vSwellST::cMsg_ytpe9LWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_2gumaBYw, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_Ip7ymV5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtT3WQTw, HV_BINOP_SUBTRACT, 0, m, &cBinop_GtT3WQTw_sendMessage);
}

void Heavy_vSwellST::cMsg_5oyN3Ata_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8Wqx9dye_sendMessage);
}

void Heavy_vSwellST::cSystem_8Wqx9dye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_khr76mDZ_sendMessage);
}

void Heavy_vSwellST::cVar_Z3p8Nmhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SbWyQP0K_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_X6Ogmiel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_X6Ogmiel, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8RulvUad, 0, m, &cDelay_8RulvUad_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8JyYJjWS, 0, m, &sTabread_8JyYJjWS_sendMessage);
}

void Heavy_vSwellST::cDelay_8RulvUad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8RulvUad, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8JyYJjWS, 0, m, &sTabread_8JyYJjWS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8RulvUad, 0, m, &cDelay_8RulvUad_sendMessage);
}

void Heavy_vSwellST::sTabread_8JyYJjWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hM1oK2ty, HV_BINOP_SUBTRACT, 0, m, &cBinop_hM1oK2ty_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_x9AEwYCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxWsv0vU, HV_BINOP_MAX, 0, m, &cBinop_kxWsv0vU_sendMessage);
}

void Heavy_vSwellST::cBinop_khr76mDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x9AEwYCd, HV_BINOP_MULTIPLY, 0, m, &cBinop_x9AEwYCd_sendMessage);
}

void Heavy_vSwellST::cBinop_GtT3WQTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VJzpQv3G_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8JyYJjWS, 0, m, &sTabread_8JyYJjWS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O7opl2on_sendMessage);
}

void Heavy_vSwellST::cSystem_nm0M74Fh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hM1oK2ty, HV_BINOP_SUBTRACT, 1, m, &cBinop_hM1oK2ty_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8RulvUad, 2, m, &cDelay_8RulvUad_sendMessage);
}

void Heavy_vSwellST::cMsg_SbWyQP0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nm0M74Fh_sendMessage);
}

void Heavy_vSwellST::cMsg_VJzpQv3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_X6Ogmiel, 0, m, &cDelay_X6Ogmiel_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8RulvUad, 0, m, &cDelay_8RulvUad_sendMessage);
}

void Heavy_vSwellST::cMsg_wIQZuIZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxWsv0vU, HV_BINOP_MAX, 1, m, &cBinop_kxWsv0vU_sendMessage);
}

void Heavy_vSwellST::cBinop_kxWsv0vU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtT3WQTw, HV_BINOP_SUBTRACT, 1, m, &cBinop_GtT3WQTw_sendMessage);
}

void Heavy_vSwellST::cCast_O7opl2on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_X6Ogmiel, 0, m, &cDelay_X6Ogmiel_sendMessage);
}

void Heavy_vSwellST::cBinop_ovewaitk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_X6Ogmiel, 2, m, &cDelay_X6Ogmiel_sendMessage);
}

void Heavy_vSwellST::cBinop_hM1oK2ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ovewaitk_sendMessage);
}

void Heavy_vSwellST::cCast_hOcwrzMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z3p8Nmhx, 0, m, &cVar_Z3p8Nmhx_sendMessage);
  cMsg_5oyN3Ata_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Ip7ymV5h, 0, m, &cTabhead_Ip7ymV5h_sendMessage);
}

void Heavy_vSwellST::cUnop_4NLUoINE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CTHrZpGc, m);
}

void Heavy_vSwellST::cCast_LUSyhNlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JsIctw6J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_UppGDGzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JPrYimt8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TlDnjcCL, 0, m, &cVar_TlDnjcCL_sendMessage);
}

void Heavy_vSwellST::cCast_AjVHjtb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Z9vpAIQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_0Z9vpAIQ_sendMessage);
}

void Heavy_vSwellST::cCast_t3jDwfXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vkkdb3Sl, 0, m, &cVar_Vkkdb3Sl_sendMessage);
}

void Heavy_vSwellST::cBinop_0Z9vpAIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OGp67hQM, 0, m, &cVar_OGp67hQM_sendMessage);
}

void Heavy_vSwellST::cSend_JPrYimt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GttxKX73_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_kSHmIXDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZHlIoBFf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_UMNDFYph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_akHKRZVr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_IOkaBw46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VULbca2O, 0, m, NULL);
}

void Heavy_vSwellST::cSend_wv4BM0yE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aLEqVVWY_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_doAKpuv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E9Anmp4B, 1, m, &cDelay_E9Anmp4B_sendMessage);
}

void Heavy_vSwellST::cBinop_n7yLk3eH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_4NLUoINE_sendMessage);
}

void Heavy_vSwellST::cReceive_s9aQ1k3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Z9vpAIQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_0Z9vpAIQ_sendMessage);
}

void Heavy_vSwellST::cReceive_FzcZMgL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1j6PXEFX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KNyeo9ax, 0, m, &cVar_KNyeo9ax_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BWkirai1, 0, m, &cVar_BWkirai1_sendMessage);
  cMsg_jR8WgIdS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yS086Bue, 0, m, &cVar_yS086Bue_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j3ijwMRX, 0, m, &cVar_j3ijwMRX_sendMessage);
  cMsg_jy8cfEu9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_So0QmUCl, 0, m, &cVar_So0QmUCl_sendMessage);
  cMsg_1eQKHN6g_sendMessage(_c, 0, m);
  cMsg_FrxV25mX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JVzi2aPH, 0, m, &cVar_JVzi2aPH_sendMessage);
  cMsg_G7TPMp6g_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sCkMkswc, 0, m, &cVar_sCkMkswc_sendMessage);
  cMsg_8zn4sdUe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IcLkf2QM, 0, m, &cTabhead_IcLkf2QM_sendMessage);
  cMsg_wIQZuIZU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Z3p8Nmhx, 0, m, &cVar_Z3p8Nmhx_sendMessage);
  cMsg_5oyN3Ata_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Ip7ymV5h, 0, m, &cTabhead_Ip7ymV5h_sendMessage);
}

void Heavy_vSwellST::cReceive_jBUannWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_jxXY6i3f, 0, m, &cSlice_jxXY6i3f_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_xllR15dY, 0, m, &cSlice_xllR15dY_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_XdCKf8vJ, 0, m, &cSlice_XdCKf8vJ_sendMessage);
}

void Heavy_vSwellST::cReceive_LjrL2X8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vNeFznDU, m);
}

void Heavy_vSwellST::cReceive_GttxKX73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e957BUig_sendMessage(_c, 0, m);
  cMsg_ceDZY6Zo_sendMessage(_c, 0, m);
  cMsg_AGPODrtl_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_A0wlJ8Bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UppGDGzX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LUSyhNlJ_sendMessage);
}

void Heavy_vSwellST::cReceive_yfGrkaFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_duNFfEoG, 1, m, &cVar_duNFfEoG_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_lrFJAaPj, 1, m, &cPack_lrFJAaPj_sendMessage);
}

void Heavy_vSwellST::cReceive_gScMmfQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_lrFJAaPj, 2, m, &cPack_lrFJAaPj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_l3F7xEMh, 1, m, &cDelay_l3F7xEMh_sendMessage);
}

void Heavy_vSwellST::cReceive_Bsrvgvdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_hfjunwSK, 1, m, &cPack_hfjunwSK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MHlOFzpa, 1, m, &cVar_MHlOFzpa_sendMessage);
}

void Heavy_vSwellST::cReceive_KtLiwKfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_hfjunwSK, 2, m, &cPack_hfjunwSK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dH9ae4wm, 1, m, &cDelay_dH9ae4wm_sendMessage);
}

void Heavy_vSwellST::cReceive_Vnn56fYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_WThK92fM, 2, m, &cPack_WThK92fM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lro5Goof, 1, m, &cDelay_lro5Goof_sendMessage);
}

void Heavy_vSwellST::cReceive_aLEqVVWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JVzi2aPH, 1, m, &cVar_JVzi2aPH_sendMessage);
  cMsg_UMNDFYph_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TlDnjcCL, 1, m, &cVar_TlDnjcCL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DIAvl0x3, 1, m, &cVar_DIAvl0x3_sendMessage);
}

void Heavy_vSwellST::cReceive_GeHXTK4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wv4BM0yE_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_649puD0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_doAKpuv9_sendMessage);
}

void Heavy_vSwellST::cReceive_oiSZxwPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ru72wZCJ, m);
}

void Heavy_vSwellST::cReceive_Z23rVpng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kyQsqv3r, m);
}

void Heavy_vSwellST::cReceive_EiGTmltp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AjVHjtb2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t3jDwfXP_sendMessage);
}

void Heavy_vSwellST::cReceive_PvJpQlN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n7yLk3eH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RHSAeQ5z, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_W1jOcfAV, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_2gumaBYw, VIf(I1));
    __hv_varread_f(&sVarf_Ru72wZCJ, VOf(Bf0));
    __hv_varread_f(&sVarf_kyQsqv3r, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_bJQv62jL, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_52wtZKA8, VOf(Bf1));
    __hv_rpole_f(&sRPole_bKv5Gk0J, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_RHSAeQ5z, VOf(Bf0));
    __hv_varread_f(&sVarf_CTHrZpGc, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_M2s9mixl, VIf(Bf2), &sEnv_M2s9mixl_sendMessage);
    __hv_tabread_f(&sTabread_8JyYJjWS, VOf(Bf2));
    __hv_line_f(&sLine_VULbca2O, VOf(Bf0));
    __hv_varread_f(&sVarf_vNeFznDU, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_6st1RsKx, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_tabread_f(&sTabread_whRWcDbe, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
