/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_VSWELLST_H_
#define _HEAVY_VSWELLST_H_

#include "HvHeavy.h"

#ifdef __cplusplus
extern "C" {
#endif

#if HV_APPLE
#pragma mark - Heavy Context
#endif

typedef enum {
  HV_VSWELLST_PARAM_IN_ATTACK_LEVEL = 0xCFF35931, // Attack_Level
  HV_VSWELLST_PARAM_IN_ATTACK_MS = 0x4397AE0, // Attack_ms
  HV_VSWELLST_PARAM_IN_MID_LEVEL = 0x73ACB90E, // Mid_Level
  HV_VSWELLST_PARAM_IN_MID_MS = 0x4675584E, // Mid_ms
  HV_VSWELLST_PARAM_IN_RELEASE_MS = 0x558F437A, // Release_ms
  HV_VSWELLST_PARAM_IN_SHAPE = 0x8D204657, // Shape
  HV_VSWELLST_PARAM_IN_SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
  HV_VSWELLST_PARAM_IN_THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
  HV_VSWELLST_PARAM_IN_THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
  HV_VSWELLST_PARAM_IN_THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
  HV_VSWELLST_PARAM_IN_TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
  HV_VSWELLST_PARAM_IN_TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
  HV_VSWELLST_PARAM_IN_TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
  HV_VSWELLST_PARAM_IN_TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
} Hv_vSwellST_ParameterIn;


/**
 * Creates a new patch instance.
 * Sample rate should be positive and in Hertz, e.g. 44100.0.
 */
HeavyContextInterface *hv_vSwellST_new(double sampleRate);

/**
 * Creates a new patch instance.
 * @param sampleRate  Sample rate should be positive (> 0) and in Hertz, e.g. 48000.0.
 * @param poolKb  Pool size is in kilobytes, and determines the maximum amount of memory
 *   allocated to messages at any time. By default this is 10 KB.
 * @param inQueueKb  The size of the input message queue in kilobytes. It determines the
 *   amount of memory dedicated to holding scheduled messages between calls to
 *   process(). Default is 2 KB.
 * @param outQueueKb  The size of the output message queue in kilobytes. It determines the
 *   amount of memory dedicated to holding scheduled messages to the default sendHook.
 *   See getNextSentMessage() for info on accessing these messages. Default is 0 KB.
 */
HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate, int poolKb, int inQueueKb, int outQueueKb);

/**
 * Free the patch instance.
 */
void hv_vSwellST_free(HeavyContextInterface *instance);


#ifdef __cplusplus
} // extern "C"
#endif

#endif // _HEAVY_VSWELLST_H_
