/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvControlTabhead.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvControlBinop.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvControlSlice.h"
#include "HvSignalEnvelope.h"
#include "HvSignalDel1.h"
#include "HvTable.h"
#include "HvControlPack.h"
#include "HvControlDelay.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvSignalRPole.h"
#include "HvControlSystem.h"
#include "HvSignalVar.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_M2s9mixl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fMTGVW5Y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_NNK7DNVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_b4RT9Tx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9NzSkhSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_x0FbXJZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FYykYu0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x3kHS0Pg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tymXmwGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2HxzK2jJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dP83YwUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CzEjdRuE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_VlSQBMvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_DNFxR5x9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lISSxcFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VJEcHYx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3mC0gsAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YAgXoqav_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iI8OBJ2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nq7RqoBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oHJqs98y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LwIBHqxX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_JxZeOLVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6OyvqgmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SlQG0OrM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_feVt2vn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CO8sBZcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Vkkdb3Sl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OGp67hQM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NNrxbLtC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fqw9gT9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0VjMGGnL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fB9wzvSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_jxXY6i3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_xllR15dY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_XdCKf8vJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BWkirai1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pvbmh7xC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_yWmRoylE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ftOjA8je_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pBFeBw8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ewe2roce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_M2tyQ6h4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DctWN2Ye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ekEHLooc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XTe1Fndb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZE9DZPRh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bXsCdnyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fwsUuYMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P0gjrMZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M1ouCamH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ec7xsVws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lgMKikgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sRKLn6BT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_l3F7xEMh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xKJ6O2wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LKR4WhHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_lrFJAaPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DIAvl0x3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e957BUig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c1aLkXJE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h4zfP9sW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1V8jH1FZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gcsNhQgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_H2NdbEFl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dH9ae4wm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ir6lI36H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zdIEnMg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_hfjunwSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_duNFfEoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ceDZY6Zo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jt1FWkD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_je6twNaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f14VtxZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FJrl89Lm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Qr2gK2zl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lro5Goof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3dHilIdY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ppwDWqaR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_WThK92fM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MHlOFzpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AGPODrtl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dLVsJRn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ueN9mk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GybXzbc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tBxHKW5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZHlIoBFf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_8n58dKBA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TlDnjcCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JVzi2aPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jR8WgIdS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bi9Ssdo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4YTt0ppQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1KNTdczd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kdEyVxzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1j6PXEFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NFtrRFfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KNyeo9ax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZETus8Yj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5aJpk6QI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KxLYFCKB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ykIvWLSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_i4U0vfdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tqkbuhYT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_KTyuMVeW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jRTnBqAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_akHKRZVr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cCJZJsX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_6c1hA2Zn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xYfjeBO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j3ijwMRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qF9YSxMI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ZzFrp4EN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yS086Bue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kJ30AjI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jIHyKB2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Wc3CAXOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_tvBQfuah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CZ7FqRSY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_69V2nvnu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XQ3xWopc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vkbTdWRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xRuStqY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_suvt6sHw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xEGDa8VM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0TzuVNEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9UqXl39l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CHcbn8aS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EtCwsW0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M251m8Pb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rswesdyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6EfTnc9M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dV4Ohg48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ayJ1eTaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_80MrvIxy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kHSZTMcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7HuCHm5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_er91PCyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gV9AlxUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_khUvHqNF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ubIB2vvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2o5svICQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y1P1lZW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PmO6luKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jiypaYcY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_23IDgafw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JsIctw6J_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_E9Anmp4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ebPLoG1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DIcqsCBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_So0QmUCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jy8cfEu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RqTZCW9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BCy1Wg9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YE8ulUuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AIal5Mry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GKEtPH6q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AKNsUOdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q4mct4nl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1eQKHN6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_52sFN3nN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hJNTUCoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nActJnXj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tRG39Adv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_0N9E3RAr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_owpVNraA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DTEzeCYX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kd4wxWfi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pJqUBRnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ycghnqEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tVlzQ3Ol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ttA6VvWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_IcLkf2QM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8zn4sdUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_d4Zl4JZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sCkMkswc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GL453hiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_twUnvqfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_whRWcDbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ejvg5FHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_puuCW3AF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1OmVGleY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RHAmK6uP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UPIHDGsI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FH2FEKNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G7TPMp6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mW65rXWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wB0CvQmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aWmEPexz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7qiZuR7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ubne2k7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FrxV25mX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OOePFlgK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h0kkHLu8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IRrpkm16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LIDhcF6x_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_PHPFy9ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ITwVLAKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ECpUwdaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VgNuLiZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NskkMo39_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uLijjDT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KqgrFa94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ytpe9LWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Ip7ymV5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5oyN3Ata_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8Wqx9dye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z3p8Nmhx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_X6Ogmiel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8RulvUad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_8JyYJjWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x9AEwYCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_khr76mDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GtT3WQTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nm0M74Fh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SbWyQP0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VJzpQv3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wIQZuIZU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kxWsv0vU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O7opl2on_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ovewaitk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hM1oK2ty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hOcwrzMY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4NLUoINE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LUSyhNlJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UppGDGzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AjVHjtb2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t3jDwfXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Z9vpAIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JPrYimt8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kSHmIXDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UMNDFYph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IOkaBw46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wv4BM0yE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_doAKpuv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n7yLk3eH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_s9aQ1k3s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FzcZMgL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jBUannWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LjrL2X8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GttxKX73_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_A0wlJ8Bh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yfGrkaFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gScMmfQd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Bsrvgvdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KtLiwKfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Vnn56fYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aLEqVVWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GeHXTK4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_649puD0e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oiSZxwPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Z23rVpng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EiGTmltp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PvJpQlN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_W1jOcfAV;
  SignalTabwrite sTabwrite_2gumaBYw;
  SignalRPole sRPole_bKv5Gk0J;
  SignalEnvelope sEnv_M2s9mixl;
  SignalTabread sTabread_8JyYJjWS;
  SignalLine sLine_VULbca2O;
  SignalTabread sTabread_whRWcDbe;
  ControlSlice cSlice_NNK7DNVE;
  ControlSlice cSlice_b4RT9Tx5;
  ControlVar cVar_9NzSkhSu;
  ControlIf cIf_x0FbXJZ5;
  ControlBinop cBinop_tymXmwGo;
  ControlSlice cSlice_VlSQBMvm;
  ControlSlice cSlice_DNFxR5x9;
  ControlVar cVar_lISSxcFD;
  ControlIf cIf_VJEcHYx0;
  ControlBinop cBinop_iI8OBJ2H;
  ControlVar cVar_Vkkdb3Sl;
  ControlVar cVar_OGp67hQM;
  ControlBinop cBinop_NNrxbLtC;
  ControlBinop cBinop_Fqw9gT9c;
  ControlSlice cSlice_jxXY6i3f;
  ControlSlice cSlice_xllR15dY;
  ControlSlice cSlice_XdCKf8vJ;
  ControlVar cVar_BWkirai1;
  ControlIf cIf_ftOjA8je;
  ControlBinop cBinop_pBFeBw8Q;
  ControlIf cIf_ewe2roce;
  ControlIf cIf_M2tyQ6h4;
  ControlIf cIf_DctWN2Ye;
  ControlIf cIf_ekEHLooc;
  ControlBinop cBinop_XTe1Fndb;
  ControlBinop cBinop_ZE9DZPRh;
  ControlBinop cBinop_bXsCdnyA;
  ControlBinop cBinop_lgMKikgF;
  ControlDelay cDelay_l3F7xEMh;
  ControlPack cPack_lrFJAaPj;
  ControlVar cVar_DIAvl0x3;
  ControlDelay cDelay_dH9ae4wm;
  ControlPack cPack_hfjunwSK;
  ControlVar cVar_duNFfEoG;
  ControlDelay cDelay_lro5Goof;
  ControlPack cPack_WThK92fM;
  ControlVar cVar_MHlOFzpa;
  ControlVar cVar_TlDnjcCL;
  ControlVar cVar_JVzi2aPH;
  SignalVarf sVarf_6st1RsKx;
  ControlDelay cDelay_1KNTdczd;
  ControlVar cVar_KNyeo9ax;
  ControlBinop cBinop_5aJpk6QI;
  ControlBinop cBinop_KxLYFCKB;
  ControlBinop cBinop_ykIvWLSy;
  ControlVar cVar_i4U0vfdc;
  ControlSlice cSlice_cCJZJsX1;
  ControlSlice cSlice_6c1hA2Zn;
  ControlVar cVar_xYfjeBO6;
  ControlVar cVar_j3ijwMRX;
  ControlVar cVar_yS086Bue;
  ControlVar cVar_kJ30AjI3;
  ControlVar cVar_jIHyKB2N;
  ControlSlice cSlice_Wc3CAXOQ;
  ControlSlice cSlice_tvBQfuah;
  ControlBinop cBinop_CZ7FqRSY;
  ControlBinop cBinop_69V2nvnu;
  ControlBinop cBinop_XQ3xWopc;
  ControlBinop cBinop_vkbTdWRR;
  ControlBinop cBinop_9xRuStqY;
  ControlBinop cBinop_0TzuVNEc;
  ControlBinop cBinop_9UqXl39l;
  ControlBinop cBinop_CHcbn8aS;
  ControlBinop cBinop_EtCwsW0v;
  ControlBinop cBinop_kHSZTMcj;
  ControlBinop cBinop_2o5svICQ;
  ControlDelay cDelay_E9Anmp4B;
  ControlVar cVar_So0QmUCl;
  ControlBinop cBinop_BCy1Wg9u;
  ControlBinop cBinop_YE8ulUuK;
  SignalVarf sVarf_52wtZKA8;
  ControlBinop cBinop_GKEtPH6q;
  ControlBinop cBinop_AKNsUOdT;
  ControlBinop cBinop_q4mct4nl;
  SignalVarf sVarf_bJQv62jL;
  ControlDelay cDelay_hJNTUCoO;
  ControlDelay cDelay_nActJnXj;
  ControlBinop cBinop_0N9E3RAr;
  HvTable hTable_owpVNraA;
  ControlBinop cBinop_kd4wxWfi;
  ControlTabhead cTabhead_IcLkf2QM;
  ControlVar cVar_sCkMkswc;
  ControlDelay cDelay_GL453hiE;
  ControlDelay cDelay_twUnvqfI;
  ControlBinop cBinop_ejvg5FHy;
  ControlBinop cBinop_puuCW3AF;
  ControlBinop cBinop_1OmVGleY;
  ControlBinop cBinop_mW65rXWH;
  ControlBinop cBinop_aWmEPexz;
  ControlBinop cBinop_7qiZuR7b;
  ControlDelay cDelay_h0kkHLu8;
  ControlDelay cDelay_IRrpkm16;
  ControlBinop cBinop_PHPFy9ky;
  HvTable hTable_ITwVLAKg;
  ControlBinop cBinop_VgNuLiZM;
  ControlTabhead cTabhead_Ip7ymV5h;
  ControlVar cVar_Z3p8Nmhx;
  ControlDelay cDelay_X6Ogmiel;
  ControlDelay cDelay_8RulvUad;
  ControlBinop cBinop_x9AEwYCd;
  ControlBinop cBinop_khr76mDZ;
  ControlBinop cBinop_GtT3WQTw;
  ControlBinop cBinop_kxWsv0vU;
  ControlBinop cBinop_ovewaitk;
  ControlBinop cBinop_hM1oK2ty;
  ControlBinop cBinop_0Z9vpAIQ;
  ControlBinop cBinop_kSHmIXDc;
  ControlBinop cBinop_doAKpuv9;
  ControlBinop cBinop_n7yLk3eH;
  SignalVarf sVarf_vNeFznDU;
  SignalVarf sVarf_Ru72wZCJ;
  SignalVarf sVarf_kyQsqv3r;
  SignalVarf sVarf_CTHrZpGc;
  SignalVarf sVarf_RHSAeQ5z;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
